% Auto-generated chapter 18 for muslim
% Hadiths in this chapter: 86

\hadithdefcmd{muslim}{3652}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى التَّمِيمِيُّ، قَالَ قَرَأْتُ عَلَى مَالِكِ بْنِ أَنَسٍ عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّهُ طَلَّقَ امْرَأَتَهُ وَهْىَ حَائِضٌ فِي عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَسَأَلَ عُمَرُ بْنُ الْخَطَّابِ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنْ ذَلِكَ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مُرْهُ فَلْيُرَاجِعْهَا ثُمَّ لْيَتْرُكْهَا حَتَّى تَطْهُرَ ثُمَّ تَحِيضَ ثُمَّ تَطْهُرَ ثُمَّ إِنْ شَاءَ أَمْسَكَ بَعْدُ وَإِنْ شَاءَ طَلَّقَ قَبْلَ أَنْ يَمَسَّ فَتِلْكَ الْعِدَّةُ الَّتِي أَمَرَ اللَّهُ عَزَّ وَجَلَّ أَنْ يُطَلَّقَ لَهَا النِّسَاءُ‏"‏ ‏.‏\hadithno{3652}\hadithtrans{Ibn 'Umar (Allah be pleased with them) reported that he divorced his wife while she was menstruating during the lifetime of Allah's Messenger (ﷺ). 'Umar b. Khattib (Allah be pleased with him) asked Allah's Messenger (ﷺ) about it, whereupon Allah's Messenger (ﷺ) said:Command him ('Abdullah b. 'Umar) to take her back (and keep her) and pronounce divorce when she is purified and she again enters the period of menstruation and she is again purified (after passing the period of menses), and then if he so desires he may keep her and if he desires divorce her (finally) before touching her (without having an intercourse with her), for that is the period of waiting ('ldda) which God, the Exalted and Glorious, has commanded for the divorce of women}}
\hadithdefcmd{muslim}{3653}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَقُتَيْبَةُ، وَابْنُ، رُمْحٍ - وَاللَّفْظُ لِيَحْيَى - قَالَ قُتَيْبَةُ حَدَّثَنَا لَيْثٌ، وَقَالَ الآخَرَانِ، أَخْبَرَنَا اللَّيْثُ بْنُ سَعْدٍ، - عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ، أَنَّهُ طَلَّقَ امْرَأَةً لَهُ وَهْىَ حَائِضٌ تَطْلِيقَةً وَاحِدَةً فَأَمَرَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يُرَاجِعَهَا ثُمَّ يُمْسِكَهَا حَتَّى تَطْهُرَ ثُمَّ تَحِيضَ عِنْدَهُ حَيْضَةً أُخْرَى ثُمَّ يُمْهِلَهَا حَتَّى تَطْهُرَ مِنْ حَيْضَتِهَا فَإِنْ أَرَادَ أَنْ يُطَلِّقَهَا فَلْيُطَلِّقْهَا حِينَ تَطْهُرُ مِنْ قَبْلِ أَنْ يُجَامِعَهَا فَتِلْكَ الْعِدَّةُ الَّتِي أَمَرَ اللَّهُ أَنْ يُطَلَّقَ لَهَا النِّسَاءُ ‏.‏ وَزَادَ ابْنُ رُمْحٍ فِي رِوَايَتِهِ وَكَانَ عَبْدُ اللَّهِ إِذَا سُئِلَ عَنْ ذَلِكَ قَالَ لأَحَدِهِمْ أَمَّا أَنْتَ طَلَّقْتَ امْرَأَتَكَ مَرَّةً أَوْ مَرَّتَيْنِ فَإِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَمَرَنِي بِهَذَا وَإِنْ كُنْتَ طَلَّقْتَهَا ثَلاَثًا فَقَدْ حَرُمَتْ عَلَيْكَ حَتَّى تَنْكِحَ زَوْجًا غَيْرَكَ وَعَصَيْتَ اللَّهَ فِيمَا أَمَرَكَ مِنْ طَلاَقِ امْرَأَتِكَ ‏.‏ قَالَ مُسْلِمٌ جَوَّدَ اللَّيْثُ فِي قَوْلِهِ تَطْلِيقَةً وَاحِدَةً ‏.‏\hadithno{3653}\hadithtrans{Abdullah (b. 'Umar) reported that he divorced a wife of his with the pronouncement of one divorce during the period of menstruation. Allah's Messenger (ﷺ) commanded him to take her back and keep her until she was purified, and then she entered the period of menses in his (house) for the second time. And he should wait until she was purified of her menses. And then if he would decide to divorce her, he should do so when she was purified before having a sexual intercourse with her; for that was the 'Idda which Allah had commanded for the divorce of women. Ibn Rumh in his narration made this addition:When 'Abdullah was asked about it, he said to one of them: If you have divorced your wife with one pronouncement or two (then you can take her back), for Allah's Messenger (ﷺ) commanded me to do it; but if you have divorced her with three pronouncements, then she is forbidden for you until she married another husband, and you disobeyed Allah in regard to the divorce of your wife what He had commanded you. (Muslim said: The word" one divorce" used by Laith is good)}}
\hadithdefcmd{muslim}{3654}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ طَلَّقْتُ امْرَأَتِي عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَهْىَ حَائِضٌ فَذَكَرَ ذَلِكَ عُمَرُ لِرَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ مُرْهُ فَلْيُرَاجِعْهَا ثُمَّ لْيَدَعْهَا حَتَّى تَطْهُرَ ثُمَّ تَحِيضَ حَيْضَةً أُخْرَى فَإِذَا طَهُرَتْ فَلْيُطَلِّقْهَا قَبْلَ أَنْ يُجَامِعَهَا أَوْ يُمْسِكْهَا فَإِنَّهَا الْعِدَّةُ الَّتِي أَمَرَ اللَّهُ أَنْ يُطَلَّقَ لَهَا النِّسَاءُ ‏"‏ ‏.‏ قَالَ عُبَيْدُ اللَّهِ قُلْتُ لِنَافِعٍ مَا صَنَعَتِ التَّطْلِيقَةُ قَالَ وَاحِدَةٌ اعْتَدَّ بِهَا ‏.‏\hadithno{3654}\hadithtrans{Ibn Umar (Allah be pleased with them) reported:I divorced my wife during the lifetime of Allah's Messenger (ﷺ) when she was in the state of menses. 'Umar (Allah be pleased with him) made a mention of it to Allah's Messenger (ﷺ), whereupon he said: Command him to take her back and leave her (in that state) until she is purified. Then (let her) enter the period of second menses, and when she is purified, then divorce her (finally) before having a sexual intercourse with her, or retain her (finally). That is the 'Idda (the prescribed period) which Allah commanded (to be kept in view) while divorcing the women. 'Ubaidullah reported: I said to Nafi': What became of that divorce (pronounced within 'Idda)? He said: It was as one which she counted}}
\hadithdefcmd{muslim}{3655}{وَحَدَّثَنَاهُ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَابْنُ الْمُثَنَّى، قَالاَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، عَنْ عُبَيْدِ اللَّهِ، بِهَذَا الإِسْنَادِ ‏.‏ نَحْوَهُ وَلَمْ يَذْكُرْ قَوْلَ عُبَيْدِ اللَّهِ لِنَافِعٍ ‏.‏ قَالَ ابْنُ الْمُثَنَّى فِي رِوَايَتِهِ فَلْيَرْجِعْهَا ‏.‏ وَقَالَ أَبُو بَكْرٍ فَلْيُرَاجِعْهَا ‏.‏\hadithno{3655}\hadithtrans{A hadith like this has been narrated on the authority of 'Ubaidullah, but he made no mention of the words of Ubaidullah that he said to Nafi}}
\hadithdefcmd{muslim}{3656}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا إِسْمَاعِيلُ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، أَنَّ ابْنَ عُمَرَ، طَلَّقَ امْرَأَتَهُ وَهْىَ حَائِضٌ فَسَأَلَ عُمَرُ النَّبِيَّ صلى الله عليه وسلم فَأَمَرَهُ أَنْ يَرْجِعَهَا ثُمَّ يُمْهِلَهَا حَتَّى تَحِيضَ حَيْضَةً أُخْرَى ثُمَّ يُمْهِلَهَا حَتَّى تَطْهُرَ ثُمَّ يُطَلِّقَهَا قَبْلَ أَنْ يَمَسَّهَا فَتِلْكَ الْعِدَّةُ الَّتِي أَمَرَ اللَّهُ أَنْ يُطَلَّقَ لَهَا النِّسَاءُ ‏.‏ قَالَ فَكَانَ ابْنُ عُمَرَ إِذَا سُئِلَ عَنِ الرَّجُلِ يُطَلِّقُ امْرَأَتَهُ وَهْىَ حَائِضٌ يَقُولُ أَمَّا أَنْتَ طَلَّقْتَهَا وَاحِدَةً أَوِ اثْنَتَيْنِ ‏.‏ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَمَرَهُ أَنْ يَرْجِعَهَا ثُمَّ يُمْهِلَهَا حَتَّى تَحِيضَ حَيْضَةً أُخْرَى ثُمَّ يُمْهِلَهَا حَتَّى تَطْهُرَ ثُمَّ يُطَلِّقَهَا قَبْلَ أَنْ يَمَسَّهَا وَأَمَّا أَنْتَ طَلَّقْتَهَا ثَلاَثًا فَقَدْ عَصَيْتَ رَبَّكَ فِيمَا أَمَرَكَ بِهِ مِنْ طَلاَقِ امْرَأَتِكَ ‏.‏ وَبَانَتْ مِنْكَ ‏.‏\hadithno{3656}\hadithtrans{Ibn 'Umar (Allah be pleased with them) reported that he divorced his wife during the period of menses. 'Umar (Allah be, pleas'ed with him) asked Allah's Apostle (ﷺ), and he commanded him ('Abdullah b. 'Umar) to have her back and then allow her respite until she enters the period of the second menses, and then allow her respite until she is purified, then divorce her (finally) before touching her (having a sexual intercourse with her), for that is the prescribed period which Allah commanded (to be kept in view) for divorcing the women. When Ibn 'Umar (Allah be pleased with them) was asked about the person who divorces his wife in the state of menses, he said:If you pronounced one divorce or two, Allah's Messenger (ﷺ) had commanded him to take her back, and then allow her respite until she enters the period of the second menses, and then allow her respite until she is purified, and then divorce her (finally) before touching her (having a sexual intercourse with her) ; and if you have pronounced (three divorces at one and the same time) you have in fact disobeyed your Lord with regard to what He commanded you about divorcing your wife. But she is however (finally separated from you)}}
\hadithdefcmd{muslim}{3657}{حَدَّثَنِي عَبْدُ بْنُ حُمَيْدٍ، أَخْبَرَنِي يَعْقُوبُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا مُحَمَّدٌ، - وَهُوَ ابْنُ أَخِي الزُّهْرِيِّ - عَنْ عَمِّهِ، أَخْبَرَنَا سَالِمُ بْنُ عَبْدِ اللَّهِ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، قَالَ طَلَّقْتُ امْرَأَتِي وَهْىَ حَائِضٌ فَذَكَرَ ذَلِكَ عُمَرُ لِلنَّبِيِّ صلى الله عليه وسلم فَتَغَيَّظَ رَسُولُ اللَّهِ صلى الله عليه وسلم ثُمَّ قَالَ ‏ "‏ مُرْهُ فَلْيُرَاجِعْهَا حَتَّى تَحِيضَ حَيْضَةً أُخْرَى مُسْتَقْبَلَةً سِوَى حَيْضَتِهَا الَّتِي طَلَّقَهَا فِيهَا فَإِنْ بَدَا لَهُ أَنْ يُطَلِّقَهَا فَلْيُطَلِّقْهَا طَاهِرًا مِنْ حَيْضَتِهَا قَبْلَ أَنْ يَمَسَّهَا فَذَلِكَ الطَّلاَقُ لِلْعِدَّةِ كَمَا أَمَرَ اللَّهُ ‏"‏ ‏.‏ وَكَانَ عَبْدُ اللَّهِ طَلَّقَهَا تَطْلِيقَةً وَاحِدَةً فَحُسِبَتْ مِنْ طَلاَقِهَا وَرَاجَعَهَا عَبْدُ اللَّهِ كَمَا أَمَرَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{3657}\hadithtrans{Abdullah b. 'Umar (Allah be pleased with them) reported:I divorced my wife while she was in the state of menses. 'Umar (Allah be pleased with him) made mention of it to Allah's Apostle (ﷺ) and he was enraged and he said: Command him to take her back until she enters the second ensuing menses other than the one in which he divorced her and in case he deems proper to divorce her, he should pronounce divorce (finally) before touching her (in the period) when she is purified of her menses, and that is the prescribed period in regard to divorce as Allah has commanded. 'Abdullah made a pronouncement of one divorce and it was counted in case of divorce. 'Abdullah took her back as Allah's Messenger (ﷺ) had commanded him}}
\hadithdefcmd{muslim}{3658}{وَحَدَّثَنِيهِ إِسْحَاقُ بْنُ مَنْصُورٍ، أَخْبَرَنَا يَزِيدُ بْنُ عَبْدِ رَبِّهِ، حَدَّثَنَا مُحَمَّدُ بْنُ حَرْبٍ، حَدَّثَنِي الزُّبَيْدِيُّ، عَنِ الزُّهْرِيِّ، بِهَذَا الإِسْنَادِ غَيْرَ أَنَّهُ قَالَ قَالَ ابْنُ عُمَرَ فَرَاجَعْتُهَا وَحَسَبْتُ لَهَا التَّطْلِيقَةَ الَّتِي طَلَّقْتُهَا ‏.‏\hadithno{3658}\hadithtrans{A hadith like this was reported on the authority of Zuhri with the same chain of narrators. Ibn Umar (Allah be pleased with them), however, said:I took her back, and counted this pronouncement of divorce (as valid) with which I divorced her}}
\hadithdefcmd{muslim}{3659}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَزُهَيْرُ بْنُ حَرْبٍ، وَابْنُ، نُمَيْرٍ - وَاللَّفْظُ لأَبِي بَكْرٍ - قَالُوا حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ، مَوْلَى آلِ طَلْحَةَ عَنْ سَالِمٍ، عَنِ ابْنِ عُمَرَ، أَنَّهُ طَلَّقَ امْرَأَتَهُ وَهْىَ حَائِضٌ فَذَكَرَ ذَلِكَ عُمَرُ لِلنَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏ "‏ مُرْهُ فَلْيُرَاجِعْهَا ثُمَّ لْيُطَلِّقْهَا طَاهِرًا أَوْ حَامِلاً ‏"‏ ‏.‏\hadithno{3659}\hadithtrans{Ibn 'Umar (Allah be pleased with them) reported that he divorced his wife while she was in the state of menses. 'Umar (Allah be pleased with him) made mention of it to Allah's Apostle (ﷺ) and he said:Command him to take her back, then divorce her when she is pure or she is pregnant}}
\hadithdefcmd{muslim}{3660}{وَحَدَّثَنِي أَحْمَدُ بْنُ عُثْمَانَ بْنِ حَكِيمٍ الأَوْدِيُّ، حَدَّثَنَا خَالِدُ بْنُ مَخْلَدٍ، حَدَّثَنِي سُلَيْمَانُ، - وَهُوَ ابْنُ بِلاَلٍ - حَدَّثَنِي عَبْدُ اللَّهِ بْنُ دِينَارٍ، عَنِ ابْنِ عُمَرَ، أَنَّهُ طَلَّقَ امْرَأَتَهُ وَهْىَ حَائِضٌ فَسَأَلَ عُمَرُ عَنْ ذَلِكَ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ مُرْهُ فَلْيُرَاجِعْهَا حَتَّى تَطْهُرَ ثُمَّ تَحِيضَ حَيْضَةً أُخْرَى ثُمَّ تَطْهُرَ ثُمَّ يُطَلِّقَ بَعْدُ أَوْ يُمْسِكَ ‏"‏ ‏.‏\hadithno{3660}\hadithtrans{Ibn 'Umar (Allah be pleased with them) reported that he divorced his wife while she was in her menses. 'Umar (Allah be pleased with him) asked Allah's Apostle (ﷺ) about that, and he said:Command him to take her back until she is pure and then she enters the second menses and then becomes pure. Then either divorce her (finally) or retain her}}
\hadithdefcmd{muslim}{3661}{وَحَدَّثَنِي عَلِيُّ بْنُ حُجْرٍ السَّعْدِيُّ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، عَنْ أَيُّوبَ، عَنِ ابْنِ، سِيرِينَ قَالَ مَكَثْتُ عِشْرِينَ سَنَةً يُحَدِّثُنِي مَنْ لاَ أَتَّهِمُ أَنَّ ابْنَ عُمَرَ طَلَّقَ امْرَأَتَهُ ثَلاَثًا وَهْىَ حَائِضٌ فَأُمِرَ أَنْ يُرَاجِعَهَا فَجَعَلْتُ لاَ أَتَّهِمُهُمْ وَلاَ أَعْرِفُ الْحَدِيثَ حَتَّى لَقِيتُ أَبَا غَلاَّبٍ يُونُسَ بْنَ جُبَيْرٍ الْبَاهِلِيَّ ‏.‏ وَكَانَ ذَا ثَبَتٍ فَحَدَّثَنِي أَنَّهُ سَأَلَ ابْنَ عُمَرَ فَحَدَّثَهُ أَنَّهُ طَلَّقَ امْرَأَتَهُ تَطْلِيقَةً وَهْىَ حَائِضٌ فَأُمِرَ أَنْ يَرْجِعَهَا - قَالَ - قُلْتُ أَفَحُسِبَتْ عَلَيْهِ قَالَ فَمَهْ ‏.‏ أَوَإِنْ عَجَزَ وَاسْتَحْمَقَ\hadithno{3661}\hadithtrans{Ibn Sirin reported:One who was blameless (as a narrator) narrated to me for twenty years that Ibn 'Umar (Allah be pleased with him) pronounced three divorces to his wife while she was in the state of menses. He was commanded to take her back. I neither blamed them (the narrators) nor recognised the hadith (to be perfectly genuine) until I met Abu Ghallab Yunus b. Jubair al-Bahili and he was very authentic, and he narrated to me that he had asked Ibn 'Umar (Allah be pleased with there) and he narrated it to him that he made one pronouncement of divorce to his wife as she was in the state of menses, but he was commanded to take her back. I said: Was it counted (as one pronouncement)? He said: Why not, was I helpless or foolish?}}
\hadithdefcmd{muslim}{3662}{وَحَدَّثَنَاهُ أَبُو الرَّبِيعِ، وَقُتَيْبَةُ، قَالاَ حَدَّثَنَا حَمَّادٌ، عَنْ أَيُّوبَ، بِهَذَا الإِسْنَادِ ‏.‏ نَحْوَهُ غَيْرَ أَنَّهُ قَالَ فَسَأَلَ عُمَرُ النَّبِيَّ صلى الله عليه وسلم فَأَمَرَهُ ‏.‏\hadithno{3662}\hadithtrans{A hadith like this has been transmitted on the authority of Ayyub with a slight variation of words}}
\hadithdefcmd{muslim}{3663}{وَحَدَّثَنَا عَبْدُ الْوَارِثِ بْنُ عَبْدِ الصَّمَدِ، حَدَّثَنِي أَبِي، عَنْ جَدِّي، عَنْ أَيُّوبَ، بِهَذَا الإِسْنَادِ وَقَالَ فِي الْحَدِيثِ فَسَأَلَ عُمَرُ النَّبِيَّ صلى الله عليه وسلم عَنْ ذَلِكَ فَأَمَرَهُ أَنْ يُرَاجِعَهَا حَتَّى يُطَلِّقَهَا طَاهِرًا مِنْ غَيْرِ جِمَاعٍ وَقَالَ ‏ "‏ يُطَلِّقُهَا فِي قُبُلِ عِدَّتِهَا ‏"‏ ‏.‏\hadithno{3663}\hadithtrans{Ayyub reported a hadith like this with the same chain of narrators and he said:Umar (Allah be pleased with him) asked Allah's Apostle (ﷺ) about it and he commanded him that he should take her back until she is divorced in the state of purity without having a sexual intercourse with her, and said: Divorce her in the beginning of her 'Idda or her 'Idda commences}}
\hadithdefcmd{muslim}{3664}{وَحَدَّثَنِي يَعْقُوبُ بْنُ إِبْرَاهِيمَ الدَّوْرَقِيُّ، عَنِ ابْنِ عُلَيَّةَ، عَنْ يُونُسَ، عَنْ مُحَمَّدِ بْنِ، سِيرِينَ عَنْ يُونُسَ بْنِ جُبَيْرٍ، قَالَ قُلْتُ لاِبْنِ عُمَرَ رَجُلٌ طَلَّقَ امْرَأَتَهُ وَهْىَ حَائِضٌ فَقَالَ أَتَعْرِفُ عَبْدَ اللَّهِ بْنَ عُمَرَ فَإِنَّهُ طَلَّقَ امْرَأَتَهُ وَهْىَ حَائِضٌ فَأَتَى عُمَرُ النَّبِيَّ صلى الله عليه وسلم فَسَأَلَهُ فَأَمَرَهُ أَنْ يَرْجِعَهَا ثُمَّ تَسْتَقْبِلَ عِدَّتَهَا ‏.‏ قَالَ فَقُلْتُ لَهُ إِذَا طَلَّقَ الرَّجُلُ امْرَأَتَهُ وَهْىَ حَائِضٌ أَتَعْتَدُّ بِتِلْكَ التَّطْلِيقَةِ فَقَالَ فَمَهْ أَوَإِنْ عَجَزَ وَاسْتَحْمَقَ\hadithno{3664}\hadithtrans{Yunus b. Jubair reported:I said to Ibn'Umar (Allah be pleased with them): A person divorcedhis wife while she was in the state of menses, whereupon he said: Do you know 'Abdullah b. Umar (Allah be pleased with them), for he divorced his wife in the state of menses. 'Umar (Allah be pleased with him) came to Allah's Apostle (ﷺ) and asked him, and he (the Holy Prophet) commanded him that he should take her back, and she started her 'Idda. I said to him: When a person divorces his wife, and she is in the state of menses, should that pronouncement of divorce be counted? He said: Why not, was he hopless or foolish?}}
\hadithdefcmd{muslim}{3665}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالَ ابْنُ الْمُثَنَّى حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، قَالَ سَمِعْتُ يُونُسَ بْنَ جُبَيْرٍ، قَالَ سَمِعْتُ ابْنَ عُمَرَ، يَقُولُ طَلَّقْتُ امْرَأَتِي وَهْىَ حَائِضٌ فَأَتَى عُمَرُ النَّبِيَّ صلى الله عليه وسلم فَذَكَرَ ذَلِكَ لَهُ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لِيُرَاجِعْهَا ‏.‏ فَإِذَا طَهَرَتْ فَإِنْ شَاءَ فَلْيُطَلِّقْهَا ‏"‏ ‏.‏ قَالَ فَقُلْتُ لاِبْنِ عُمَرَ أَفَاحْتَسَبْتَ بِهَا قَالَ مَا يَمْنَعُهُ ‏.‏ أَرَأَيْتَ إِنْ عَجَزَ وَاسْتَحْمَقَ\hadithno{3665}\hadithtrans{Ibn 'Umar (Allah be pleased with them) reported:I divorced my wife while she was in the state of menses. 'Umar (Allah he pleased wish him) came toAllah's Apostle (ﷺ) and made mention of that to him, whereupon Allah's Apostle (ﷺ) told that be should take her back, and when she is pure he may divorce her. if he would so wish. I (one of the narrators) said to Ibn 'Umar (Allah be pleased with them): Did you count (this pronouncement of divorce) in her case? He said: What (after all) prevents him from doing so? Do you find him (Ibn Umar) either helpless or foolish?}}
\hadithdefcmd{muslim}{3666}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا خَالِدُ بْنُ عَبْدِ اللَّهِ، عَنْ عَبْدِ الْمَلِكِ، عَنْ أَنَسِ بْنِ، سِيرِينَ قَالَ سَأَلْتُ ابْنَ عُمَرَ عَنِ امْرَأَتِهِ الَّتِي، طَلَّقَ فَقَالَ طَلَّقْتُهَا وَهْىَ حَائِضٌ فَذُكِرَ ذَلِكَ لِعُمَرَ فَذَكَرَهُ لِلنَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏ "‏ مُرْهُ فَلْيُرَاجِعْهَا فَإِذَا طَهَرَتْ فَلْيُطَلِّقْهَا لِطُهْرِهَا ‏"‏ ‏.‏ قَالَ فَرَاجَعْتُهَا ثُمَّ طَلَّقْتُهَا لِطُهْرِهَا ‏.‏ قُلْتُ فَاعْتَدَدْتَ بِتِلْكَ التَّطْلِيقَةِ الَّتِي طَلَّقْتَ وَهْىَ حَائِضٌ قَالَ مَا لِيَ لاَ أَعْتَدُّ بِهَا وَإِنْ كُنْتُ عَجَزْتُ وَاسْتَحْمَقْتُ ‏.‏\hadithno{3666}\hadithtrans{Anas b. Sirin reported:I asked Ibn 'Umar (Allah be pleased with them) about the woman whom he had divorced. He said: I divorced her while she was in the state of menses. It was mentioned to 'Umar (Allah be pleased with him) and he then made a mention of that to Allah's Apostle (ﷺ), whereupon he said: Command him to take her back and when the period of menses is over, then (he may divorce her in the state of her purity. He (Ibn Umar) said: So I took her back, then divorced her in her purity. I (the narrator) said: Did you count that divorce which you pronounced in the state of menses? He said: Why should I not have counted that? Was I helpless or foolish?}}
\hadithdefcmd{muslim}{3667}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالَ ابْنُ الْمُثَنَّى حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ أَنَسِ بْنِ سِيرِينَ، أَنَّهُ سَمِعَ ابْنَ عُمَرَ، قَالَ طَلَّقْتُ امْرَأَتِي وَهْىَ حَائِضٌ فَأَتَى عُمَرُ النَّبِيَّ صلى الله عليه وسلم فَأَخْبَرَهُ فَقَالَ ‏ "‏ مُرْهُ فَلْيُرَاجِعْهَا ثُمَّ إِذَا طَهَرَتْ فَلْيُطَلِّقْهَا ‏" ‏.‏ قُلْتُ لاِبْنِ عُمَرَ أَفَاحْتَسَبْتَ بِتِلْكَ التَّطْلِيقَةِ قَالَ فَمَهْ ‏.‏\hadithno{3667}\hadithtrans{Anas b. Sirin reported that he had heard Ibn 'Umar (Allah be pleased with them) as saying. I divorced my wife while she was in the state of menses. 'Umar (Allah be pleased with him) came to Allah's Apostle (ﷺ) and informed him about it, whereupon he (Allah's Apostle) said:Command him to take her back and when she is pure, then divorce her. I said to Ibn 'Umar Allah be pleased with them): Did you count that pronouncement of divorce? He said: Why not?}}
\hadithdefcmd{muslim}{3668}{وَحَدَّثَنِيهِ يَحْيَى بْنُ حَبِيبٍ، حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، ح وَحَدَّثَنِيهِ عَبْدُ الرَّحْمَنِ بْنُ، بِشْرٍ حَدَّثَنَا بَهْزٌ، قَالاَ حَدَّثَنَا شُعْبَةُ، بِهَذَا الإِسْنَادِ غَيْرَ أَنَّ فِي، حَدِيثِهِمَا ‏ "‏ لِيَرْجِعْهَا ‏"‏ ‏.‏ وَفِي حَدِيثِهِمَا قَالَ قُلْتُ لَهُ أَتَحْتَسِبُ بِهَا قَالَ فَمَهْ ‏.‏\hadithno{3668}\hadithtrans{This hadith has been narrated on the authority of Shu'ba with the same chain of transmitters but with a slight variation in wording}}
\hadithdefcmd{muslim}{3669}{وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي ابْنُ طَاوُسٍ، عَنْ أَبِيهِ، أَنَّهُ سَمِعَ ابْنَ عُمَرَ، يُسْأَلُ عَنْ رَجُلٍ، طَلَّقَ امْرَأَتَهُ حَائِضًا فَقَالَ أَتَعْرِفُ عَبْدَ اللَّهِ بْنَ عُمَرَ قَالَ نَعَمْ ‏.‏ قَالَ فَإِنَّهُ طَلَّقَ امْرَأَتَهُ حَائِضًا فَذَهَبَ عُمَرُ إِلَى النَّبِيِّ صلى الله عليه وسلم فَأَخْبَرَهُ الْخَبَرَ فَأَمَرَهُ أَنْ يُرَاجِعَهَا قَالَ لَمْ أَسْمَعْهُ يَزِيدُ عَلَى ذَلِكَ لأَبِيهِ‏.‏\hadithno{3669}\hadithtrans{Ibn Tawus narrated on the authority of his father that Ibn 'Umar (Allah be pleased with them) was asked about the person who divorced his wife in the state of menses, whereupon he said:Do you know 'Abdullah b. Umar? He said: Yes. He said: It was he who divorced his wife jn the state of menses and 'Umar went to Allah's Apostle (ﷺ) and gave him this information. and he commanded him that he should take her back; and he (Abu Tawus) said: I did not hear any addition to this (hadith) from my father}}
\hadithdefcmd{muslim}{3670}{وَحَدَّثَنِي هَارُونُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا حَجَّاجُ بْنُ مُحَمَّدٍ، قَالَ قَالَ ابْنُ جُرَيْجٍ أَخْبَرَنِي أَبُو الزُّبَيْرِ، أَنَّهُ سَمِعَ عَبْدَ الرَّحْمَنِ بْنَ أَيْمَنَ، مَوْلَى عَزَّةَ يَسْأَلُ ابْنَ عُمَرَ وَأَبُو الزُّبَيْرِ يَسْمَعُ ذَلِكَ كَيْفَ تَرَى فِي رَجُلٍ طَلَّقَ امْرَأَتَهُ حَائِضًا فَقَالَ طَلَّقَ ابْنُ عُمَرَ امْرَأَتَهُ وَهْىَ حَائِضٌ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَسَأَلَ عُمَرُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ إِنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ طَلَّقَ امْرَأَتَهُ وَهْىَ حَائِضٌ ‏.‏ فَقَالَ لَهُ النَّبِيُّ صلى الله عليه وسلم ‏"‏ لِيُرَاجِعْهَا ‏"‏ ‏.‏ فَرَدَّهَا وَقَالَ ‏"‏ إِذَا طَهَرَتْ فَلْيُطَلِّقْ أَوْ لِيُمْسِكْ ‏"‏ ‏.‏ قَالَ ابْنُ عُمَرَ وَقَرَأَ النَّبِيُّ صلى الله عليه وسلم يَا أَيُّهَا النَّبِيُّ إِذَا طَلَّقْتُمُ النِّسَاءَ فَطَلِّقُوهُنَّ فِي قُبُلِ عِدَّتِهِنَّ ‏.‏\hadithno{3670}\hadithtrans{Abu Zubair reported that he heard 'Abd al-Rahman b. Aiman (the freed slave of 'Azza) say that he asked Ibn 'Umar (Allah be pleased with them) and Abu Zubair heard:What is your opinion about the person who divorced his wife in the state of menses? Thereupon he said: Ibn Umar (Allah be pleased with them) divorced his wife during the lifetime of Allah's Messenger (ﷺ) while she was in the state of menses. Upon this Allah's Messenger (ﷺ) told him to take her back and so he took her back and he (further) said: When she is pure, then either divorce her or retain her. Ibn 'Umar (Allah be pleased with them) said that Allah's Apostle (ﷺ) then recited this verse:" O Apostle, when you divorce women, divorce them at the commencement of their prescribed period" (Ixv)}}
\hadithdefcmd{muslim}{3671}{وَحَدَّثَنِي هَارُونُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا أَبُو عَاصِمٍ، عَنِ ابْنِ جُرَيْجٍ، عَنْ أَبِي الزُّبَيْرِ، عَنِ ابْنِ عُمَرَ، ‏.‏ نَحْوَ هَذِهِ الْقِصَّةِ ‏.‏\hadithno{3671}\hadithtrans{The story in the above hadith has likewise been narrated through another chain}}
\hadithdefcmd{muslim}{3672}{وَحَدَّثَنِيهِ مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي أَبُو الزُّبَيْرِ، أَنَّهُ سَمِعَ عَبْدَ الرَّحْمَنِ بْنَ أَيْمَنَ، مَوْلَى عُرْوَةَ يَسْأَلُ ابْنَ عُمَرَ وَأَبُو الزُّبَيْرِ يَسْمَعُ بِمِثْلِ حَدِيثِ حَجَّاجٍ وَفِيهِ بَعْضُ الزِّيَادَةِ ‏.‏ قَالَ مُسْلِمٌ أَخْطَأَ حَيْثُ قَالَ عُرْوَةَ إِنَّمَا هُوَ مَوْلَى عَزَّةَ ‏.‏\hadithno{3672}\hadithtrans{A hadith like this is reported on the same authority (but with this difference that the narrator) 'Abd al-Rahman b. Aiman (was mentioned) as the freed slave of 'Urwa (Imam Muslim said:He made a mistake who said that it was 'Urwa; it was in fact the freed slave of 'Azza)}}
\hadithdefcmd{muslim}{3673}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَمُحَمَّدُ بْنُ رَافِعٍ، - وَاللَّفْظُ لاِبْنِ رَافِعٍ - قَالَ إِسْحَاقُ أَخْبَرَنَا وَقَالَ ابْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ ابْنِ طَاوُسٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ كَانَ الطَّلاَقُ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَأَبِي بَكْرٍ وَسَنَتَيْنِ مِنْ خِلاَفَةِ عُمَرَ طَلاَقُ الثَّلاَثِ وَاحِدَةً فَقَالَ عُمَرُ بْنُ الْخَطَّابِ إِنَّ النَّاسَ قَدِ اسْتَعْجَلُوا فِي أَمْرٍ قَدْ كَانَتْ لَهُمْ فِيهِ أَنَاةٌ فَلَوْ أَمْضَيْنَاهُ عَلَيْهِمْ ‏.‏ فَأَمْضَاهُ عَلَيْهِمْ ‏.‏\hadithno{3673}\hadithtrans{Ibn 'Abbas (Allah be pleased with them) reported that the (pronouncement) of three divorces during the lifetime of Allah's Messenger (ﷺ) and that of Abu Bakr and two years of the caliphate of Umar (Allah be pleased with him) (was treated) as one. But Umar b. Khattab (Allah be pleased with him) said:Verily the people have begun to hasten in the matter in which they are required to observe respite. So if we had imposed this upon them, and he imposed it upon them}}
\hadithdefcmd{muslim}{3674}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا رَوْحُ بْنُ عُبَادَةَ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، ح وَحَدَّثَنَا ابْنُ رَافِعٍ، - وَاللَّفْظُ لَهُ - حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي ابْنُ طَاوُسٍ، عَنْ أَبِيهِ، أَنَّ أَبَا الصَّهْبَاءِ، قَالَ لاِبْنِ عَبَّاسٍ أَتَعْلَمُ أَنَّمَا كَانَتِ الثَّلاَثُ تُجْعَلُ وَاحِدَةً عَلَى عَهْدِ النَّبِيِّ صلى الله عليه وسلم وَأَبِي بَكْرٍ وَثَلاَثًا مِنْ إِمَارَةِ عُمَرَ ‏.‏ فَقَالَ ابْنُ عَبَّاسٍ نَعَمْ ‏.‏\hadithno{3674}\hadithtrans{Abu Sahba' said toIbn 'Abbas (Allah be pleased with them):Do you know that three (divorces) were treated as one during the lifetime of Allah's Apostle (ﷺ), and that of Abu Bakr, and during three (years) of the caliphate of Umar (Allah be pleased with him)? Ibn Abbas (Allah be pleased with them) said: Yes}}
\hadithdefcmd{muslim}{3675}{وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا سُلَيْمَانُ بْنُ حَرْبٍ، عَنْ حَمَّادِ بْنِ زَيْدٍ، عَنْ أَيُّوبَ السَّخْتِيَانِيِّ، عَنْ إِبْرَاهِيمَ بْنِ مَيْسَرَةَ، عَنْ طَاوُسٍ، أَنَّ أَبَا الصَّهْبَاءِ، قَالَ لاِبْنِ عَبَّاسٍ هَاتِ مِنْ هَنَاتِكَ أَلَمْ يَكُنِ الطَّلاَقُ الثَّلاَثُ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَأَبِي بَكْرٍ وَاحِدَةً فَقَالَ قَدْ كَانَ ذَلِكَ فَلَمَّا كَانَ فِي عَهْدِ عُمَرَ تَتَايَعَ النَّاسُ فِي الطَّلاَقِ فَأَجَازَهُ عَلَيْهِمْ ‏.‏\hadithno{3675}\hadithtrans{Abu al-Sahba' said to Ibn 'Abbas:Enlighten us with your information whether the three divorces (pronounced at one and the same time) were not treated as one during the lifetime of Allah's Messenger (ﷺ) and Abu Bakr. He said: It was in fact so, but when during the caliphate of 'Umar (Allah be pleased with him) people began to pronounce divorce frequently, he allowed them to do so (to treat pronouncements of three divorces in a single breath as one)}}
\hadithdefcmd{muslim}{3676}{وَحَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، عَنْ هِشَامٍ، - يَعْنِي الدَّسْتَوَائِيَّ - قَالَ كَتَبَ إِلَىَّ يَحْيَى بْنُ أَبِي كَثِيرٍ يُحَدِّثُ عَنْ يَعْلَى بْنِ حَكِيمٍ عَنْ سَعِيدِ بْنِ جُبَيْرٍ عَنِ ابْنِ عَبَّاسٍ أَنَّهُ كَانَ يَقُولُ فِي الْحَرَامِ يَمِينٌ يُكَفِّرُهَا ‏.‏ وَقَالَ ابْنُ عَبَّاسٍ ‏\{‏ لَقَدْ كَانَ لَكُمْ فِي رَسُولِ اللَّهِ أُسْوَةٌ حَسَنَةٌ‏\}‏ ‏.‏\hadithno{3676}\hadithtrans{Ibn Abbas (Allah be pleased with them) reported about (declaring of one's woman) unlawful as an oath which must be atoned, and Ibn 'Abbas said:Verily, there is in the Messenger of Allah (ﷺ) a model pattern for you}}
\hadithdefcmd{muslim}{3677}{حَدَّثَنَا يَحْيَى بْنُ بِشْرٍ الْحَرِيرِيُّ، حَدَّثَنَا مُعَاوِيَةُ، - يَعْنِي ابْنَ سَلاَّمٍ - عَنْ يَحْيَى، بْنِ أَبِي كَثِيرٍ أَنَّ يَعْلَى بْنَ حَكِيمٍ، أَخْبَرَهُ أَنَّ سَعِيدَ بْنَ جُبَيْرٍ أَخْبَرَهُ أَنَّهُ، سَمِعَ ابْنَ عَبَّاسٍ، قَالَ إِذَا حَرَّمَ الرَّجُلُ عَلَيْهِ امْرَأَتَهُ فَهْىَ يَمِينٌ يُكَفِّرُهَا وَقَالَ ‏\{‏ لَقَدْ كَانَ لَكُمْ فِي رَسُولِ اللَّهِ أُسْوَةٌ حَسَنَةٌ‏\}‏\hadithno{3677}\hadithtrans{Ibn Abbas (Allah be pleased with them) reported:When a man declares his wife unlawful for himself that is an oath which must be atoned, and he said: There is in the Messenger of Allah (ﷺ) a noble pattern for you}}
\hadithdefcmd{muslim}{3678}{وَحَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا حَجَّاجُ بْنُ مُحَمَّدٍ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي عَطَاءٌ، أَنَّهُ سَمِعَ عُبَيْدَ بْنَ عُمَيْرٍ، يُخْبِرُ أَنَّهُ سَمِعَ عَائِشَةَ، تُخْبِرُ أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَمْكُثُ عِنْدَ زَيْنَبَ بِنْتِ جَحْشٍ فَيَشْرَبُ عِنْدَهَا عَسَلاً قَالَتْ فَتَوَاطَأْتُ أَنَا وَحَفْصَةُ أَنَّ أَيَّتَنَا مَا دَخَلَ عَلَيْهَا النَّبِيُّ صلى الله عليه وسلم فَلْتَقُلْ إِنِّي أَجِدُ مِنْكَ رِيحَ مَغَافِيرَ أَكَلْتَ مَغَافِيرَ فَدَخَلَ عَلَى إِحْدَاهُمَا فَقَالَتْ ذَلِكَ لَهُ ‏.‏ فَقَالَ ‏"‏ بَلْ شَرِبْتُ عَسَلاً عِنْدَ زَيْنَبَ بِنْتِ جَحْشٍ وَلَنْ أَعُودَ لَهُ ‏"‏ ‏.‏ فَنَزَلَ ‏\{‏ لِمَ تُحَرِّمُ مَا أَحَلَّ اللَّهُ لَكَ‏\}‏ إِلَى قَوْلِهِ ‏\{‏ إِنْ تَتُوبَا‏\}‏ لِعَائِشَةَ وَحَفْصَةَ ‏\{‏ وَإِذْ أَسَرَّ النَّبِيُّ إِلَى بَعْضِ أَزْوَاجِهِ حَدِيثًا‏\}‏ لِقَوْلِهِ ‏"‏ بَلْ شَرِبْتُ عَسَلاً ‏"‏ ‏.‏\hadithno{3678}\hadithtrans{A'isha (Allah be pleased with her) narrated that Allah's Apostle (ﷺ) used to spend time with Zainab daughter of Jahsh and drank honey at her house. She ('A'isha further) said:I and Hafsa agreed that one whom Allah's Apostle (ﷺ) would visit first should say: I notice that you have an odour of the Maghafir (gum of mimosa). He (the Holy Prophet) visited one of them and she said to him like this, whereupon he said: I have taken honey in the house of Zainab bint Jabsh and I will never do it again. It was at this (that the following verse was revealed): 'Why do you hold to be forbidden what Allah has made lawful for you... (up to). If you both ('A'isha and Hafsa) turn to Allah" up to:" And when the Prophet confided an information to one of his wives" (lxvi. 3). This refers to his saying: But I have taken honey}}
\hadithdefcmd{muslim}{3679}{حَدَّثَنَا أَبُو كُرَيْبٍ، مُحَمَّدُ بْنُ الْعَلاَءِ وَهَارُونُ بْنُ عَبْدِ اللَّهِ قَالاَ حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُحِبُّ الْحَلْوَاءَ وَالْعَسَلَ فَكَانَ إِذَا صَلَّى الْعَصْرَ دَارَ عَلَى نِسَائِهِ فَيَدْنُو مِنْهُنَّ فَدَخَلَ عَلَى حَفْصَةَ فَاحْتَبَسَ عِنْدَهَا أَكْثَرَ مِمَّا كَانَ يَحْتَبِسُ فَسَأَلْتُ عَنْ ذَلِكَ فَقِيلَ لِي أَهْدَتْ لَهَا امْرَأَةٌ مِنْ قَوْمِهَا عُكَّةً مِنْ عَسَلٍ فَسَقَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم مِنْهُ شَرْبَةً فَقُلْتُ أَمَا وَاللَّهِ لَنَحْتَالَنَّ لَهُ ‏.‏ فَذَكَرْتُ ذَلِكَ لِسَوْدَةَ وَقُلْتُ إِذَا دَخَلَ عَلَيْكِ فَإِنَّهُ سَيَدْنُو مِنْكِ فَقُولِي لَهُ يَا رَسُولَ اللَّهِ أَكَلْتَ مَغَافِيرَ فَإِنَّهُ سَيَقُولُ لَكِ لاَ ‏.‏ فَقُولِي لَهُ مَا هَذِهِ الرِّيحُ وَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَشْتَدُّ عَلَيْهِ أَنْ يُوجَدَ مِنْهُ الرِّيحُ - فَإِنَّهُ سَيَقُولُ لَكِ سَقَتْنِي حَفْصَةُ شَرْبَةَ عَسَلٍ ‏.‏ فَقُولِي لَهُ جَرَسَتْ نَحْلُهُ الْعُرْفُطَ وَسَأَقُولُ ذَلِكَ لَهُ وَقُولِيهِ أَنْتِ يَا صَفِيَّةُ فَلَمَّا دَخَلَ عَلَى سَوْدَةَ قَالَتْ تَقُولُ سَوْدَةُ وَالَّذِي لاَ إِلَهَ إِلاَّ هُوَ لَقَدْ كِدْتُ أَنْ أُبَادِئَهُ بِالَّذِي قُلْتِ لِي وَإِنَّهُ لَعَلَى الْبَابِ فَرَقًا مِنْكِ فَلَمَّا دَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَتْ يَا رَسُولَ اللَّهِ أَكَلْتَ مَغَافِيرَ قَالَ ‏"‏ لاَ ‏"‏ ‏.‏ قَالَتْ فَمَا هَذِهِ الرِّيحُ قَالَ ‏"‏ سَقَتْنِي حَفْصَةُ شَرْبَةَ عَسَلٍ ‏"‏ ‏.‏ قَالَتْ جَرَسَتْ نَحْلُهُ الْعُرْفُطَ ‏.‏ فَلَمَّا دَخَلَ عَلَىَّ قُلْتُ لَهُ مِثْلَ ذَلِكَ ثُمَّ دَخَلَ عَلَى صَفِيَّةَ فَقَالَتْ بِمِثْلِ ذَلِكَ فَلَمَّا دَخَلَ عَلَى حَفْصَةَ قَالَتْ يَا رَسُولَ اللَّهِ أَلاَ أَسْقِيكَ مِنْهُ قَالَ ‏"‏ لاَ حَاجَةَ لِي بِهِ ‏"‏ ‏.‏ قَالَتْ تَقُولُ سَوْدَةُ سُبْحَانَ اللَّهِ وَاللَّهِ لَقَدْ حَرَمْنَاهُ ‏.‏ قَالَتْ قُلْتُ لَهَا اسْكُتِي ‏.‏\hadithno{3679}\hadithtrans{A'isha (Allah be pleased with her) reported Allah's Messenger (ﷺ) liked sweet (dish) and honey. After saying the afternoon prayer he used to visit his wives going close to them. So he went to Hafsa and stayed with her more than what was his usual stay. I ('A'isha) asked about that. It was said to me:A woman of her family had sent her a small vessel of honey as a gift, and she gave to Allah's Messenger (ﷺ) from that a drink. I said: By Allah, we would also contrive a device for him. I mentioned that to Sauda, and said: When he (Allah's Apostle) would visit you and draw close to you, say to him: Allah's Messenger, have you taken maghafir? And he would'say to you: No. Then say to him: What is this odour? And Allah's Messenger (ﷺ) felt it very much that unpleasant odour should emit from him. So he would say to you: Hafsa has given me a drink of honey. Then you should say to him: The honey-bees might have sucked 'Urfut, and I would also say the same to him and. Safiyya, you should also say this. So when he (the Holy Prophet) came to Sauda, she said: By Him besides whom there is no god, it was under compulsion that I had decided to state that which you told me when he would be at a little distance at the door. So when Allah's Messenger (ﷺ) came near, she said: Messenger of Allah, did you eat Maghafir? He said: No. She (again) said: Then what is this odour? He said: Hafsa gave me honey to drink. She said: The honey-bee might have sucked 'Urfut. When he came to me I told him like this. He then visited Safiyya and she also said to him like this. When he (again) visited Hafsa, she said: Messenger of Allah, should I not give you that (drink)? He said: I do not need that. Sauda said: Hallowed be Allah, by Him we have (contrived) to make that (honey) unlawful for him. I said to her: Keep quiet}}
\hadithdefcmd{muslim}{3680}{قَالَ أَبُو إِسْحَاقَ إِبْرَاهِيمُ حَدَّثَنَا الْحَسَنُ بْنُ بِشْرِ بْنِ الْقَاسِمِ، حَدَّثَنَا أَبُو أُسَامَةَ، بِهَذَا سَوَاءً وَحَدَّثَنِيهِ سُوَيْدُ بْنُ سَعِيدٍ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، بِهَذَا الإِسْنَادِ نَحْوَهُ ‏.‏\hadithno{3680}\hadithtrans{This hadith has been narrated on the authority of 'Urwa with the same chain of transmitters}}
\hadithdefcmd{muslim}{3681}{وَحَدَّثَنِي أَبُو الطَّاهِرِ، حَدَّثَنَا ابْنُ وَهْبٍ، ح وَحَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى التُّجِيبِيُّ، - وَاللَّفْظُ لَهُ - أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ بْنُ يَزِيدَ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَنِي أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ، أَنَّ عَائِشَةَ، قَالَتْ لَمَّا أُمِرَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِتَخْيِيرِ أَزْوَاجِهِ بَدَأَ بِي فَقَالَ ‏"‏ إِنِّي ذَاكِرٌ لَكِ أَمْرًا فَلاَ عَلَيْكِ أَنْ لاَ تَعْجَلِي حَتَّى تَسْتَأْمِرِي أَبَوَيْكِ ‏"‏ ‏.‏ قَالَتْ قَدْ عَلِمَ أَنَّ أَبَوَىَّ لَمْ يَكُونَا لِيَأْمُرَانِي بِفِرَاقِهِ قَالَتْ ثُمَّ قَالَ ‏"‏ إِنَّ اللَّهَ عَزَّ وَجَلَّ قَالَ ‏\{‏ يَا أَيُّهَا النَّبِيُّ قُلْ لأَزْوَاجِكَ إِنْ كُنْتُنَّ تُرِدْنَ الْحَيَاةَ الدُّنْيَا وَزِينَتَهَا فَتَعَالَيْنَ أُمَتِّعْكُنَّ وَأُسَرِّحْكُنَّ سَرَاحًا جَمِيلاً * وَإِنْ كُنْتُنَّ تُرِدْنَ اللَّهَ وَرَسُولَهُ وَالدَّارَ الآخِرَةَ فَإِنَّ اللَّهَ أَعَدَّ لِلْمُحْسِنَاتِ مِنْكُنَّ أَجْرًا عَظِيمًا‏\}‏ قَالَتْ فَقُلْتُ فِي أَىِّ هَذَا أَسْتَأْمِرُ أَبَوَىَّ فَإِنِّي أُرِيدُ اللَّهَ وَرَسُولَهُ وَالدَّارَ الآخِرَةَ ‏.‏ قَالَتْ ثُمَّ فَعَلَ أَزْوَاجُ رَسُولِ اللَّهِ صلى الله عليه وسلم مِثْلَ مَا فَعَلْتُ ‏.‏\hadithno{3681}\hadithtrans{A'isha (Allah be pleased with her) reported:When the Messenger of Allah (ﷺ) was commanded to give option to his wives, he started it from me saying: I am going to mention to you a matter which you should not (decide) in haste until you have consulted your parents. She said that he already knew that my parents would never allow me to seek separation from him She said: Then he said: Allah, the Exalted and Glorious, said: Prophet, say to thy wives: If you desire this world's life and its adornment, then come, I will give you a provision and allow you to depart a goodly departing; and if you desire Allah and His Messenger and the abode of the Hereafter, then Allah has prepared for the doers of good among you a great reward She is reported to have said: About what should I consult my parents, for I desire Allah and His Messenger and the abode of the Hereafter? She ('A'isha) said: Then all the wives of Allah's Messenger (ﷺ) did as I had done}}
\hadithdefcmd{muslim}{3682}{حَدَّثَنَا سُرَيْجُ بْنُ يُونُسَ، حَدَّثَنَا عَبَّادُ بْنُ عَبَّادٍ، عَنْ عَاصِمٍ، عَنْ مُعَاذَةَ الْعَدَوِيَّةِ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَسْتَأْذِنُنَا إِذَا كَانَ فِي يَوْمِ الْمَرْأَةِ مِنَّا بَعْدَ مَا نَزَلَتْ ‏\{‏ تُرْجِي مَنْ تَشَاءُ مِنْهُنَّ وَتُؤْوِي إِلَيْكَ مَنْ تَشَاءُ‏\}‏ فَقَالَتْ لَهَا مُعَاذَةُ فَمَا كُنْتِ تَقُولِينَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم إِذَا اسْتَأْذَنَكِ قَالَتْ كُنْتُ أَقُولُ إِنْ كَانَ ذَاكَ إِلَىَّ لَمْ أُوثِرْ أَحَدًا عَلَى نَفْسِي ‏.‏\hadithno{3682}\hadithtrans{A'isha (Allah be pleased with her) reported that Allah's Messenger (ﷺ) sought our permission when he had a (turn to spend) a day with (one of his wives) amongst us (whereas he wanted to visit his other wives too). It was after this that this verse was revealed:" Thou mayest put off whom thou pleasest of them, and take for thee whom thou pleasest" (xxxiii. 5). Mu'adha said to her: What did you say to Allah's Messenger (ﷺ) when he sought your permission? She said: I used to say: If it had the option in this I would not have (allowed anyone) to have precedence over me}}
\hadithdefcmd{muslim}{3683}{وَحَدَّثَنَاهُ الْحَسَنُ بْنُ عِيسَى، أَخْبَرَنَا ابْنُ الْمُبَارَكِ، أَخْبَرَنَا عَاصِمٌ، بِهَذَا الإِسْنَادِ ‏.‏ نَحْوَهُ ‏.‏\hadithno{3683}\hadithtrans{The above hadith has likewise been narrated through another chain}}
\hadithdefcmd{muslim}{3684}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى التَّمِيمِيُّ، أَخْبَرَنَا عَبْثَرٌ، عَنْ إِسْمَاعِيلَ بْنِ أَبِي خَالِدٍ، عَنِ الشَّعْبِيِّ، عَنْ مَسْرُوقٍ، قَالَ قَالَتْ عَائِشَةُ قَدْ خَيَّرَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَلَمْ نَعُدَّهُ طَلاَقًا ‏.‏\hadithno{3684}\hadithtrans{A'isha reported:Allah's Messenger (ﷺ) gave us the option (to get divorce) but we did not deem it as divorce}}
\hadithdefcmd{muslim}{3685}{وَحَدَّثَنَاهُ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنْ إِسْمَاعِيلَ بْنِ أَبِي، خَالِدٍ عَنِ الشَّعْبِيِّ، عَنْ مَسْرُوقٍ، قَالَ مَا أُبَالِي خَيَّرْتُ امْرَأَتِي وَاحِدَةً أَوْ مِائَةً أَوْ أَلْفًا بَعْدَ أَنْ تَخْتَارَنِي وَلَقَدْ سَأَلْتُ عَائِشَةَ فَقَالَتْ قَدْ خَيَّرَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم أَفَكَانَ طَلاَقًا\hadithno{3685}\hadithtrans{Masruq reported:I do not mind if I give option to my wife (to get divorce) once, hundred times, or thousand times after (knowing it) that she has chosen me (and would never seek divorce). I asked 'A'isha (Allah be pleased with her) (about it) and she said: Allah's Messenger (ﷺ) gave us the option, but did it imply divorce? (It was in fact not a divorce; it is effective when women actually avail themselves of it)}}
\hadithdefcmd{muslim}{3686}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ عَاصِمٍ، عَنِ الشَّعْبِيِّ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم خَيَّرَ نِسَاءَهُ فَلَمْ يَكُنْ طَلاَقًا‏.‏\hadithno{3686}\hadithtrans{A'isha reported that Allah's Messenger (ﷺ) gave option to his wives, but it was not a divorce}}
\hadithdefcmd{muslim}{3687}{وَحَدَّثَنِي إِسْحَاقُ بْنُ مَنْصُورٍ، أَخْبَرَنَا عَبْدُ الرَّحْمَنِ، عَنْ سُفْيَانَ، عَنْ عَاصِمٍ الأَحْوَلِ، وَإِسْمَاعِيلَ بْنِ أَبِي خَالِدٍ عَنِ الشَّعْبِيِّ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، قَالَتْ خَيَّرَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَاخْتَرْنَاهُ فَلَمْ يَعُدَّهُ طَلاَقًا ‏.‏\hadithno{3687}\hadithtrans{A'isha (Allah be pleased with her) reported:Allah's Messenger (ﷺ) gave us the option (to get divorce) and we chose him and he did not count it a divorce}}
\hadithdefcmd{muslim}{3688}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ وَأَبُو كُرَيْبٍ قَالَ يَحْيَى أَخْبَرَنَا وَقَالَ الآخَرَانِ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ مُسْلِمٍ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، قَالَتْ خَيَّرَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَاخْتَرْنَاهُ فَلَمْ يَعْدُدْهَا عَلَيْنَا شَيْئًا ‏.‏\hadithno{3688}\hadithtrans{A'isha (Allah be pleased with her) reported:Allah's Messeinger (ﷺ) gave us the option (to get divorce), but me made a choice of him and he did not count anything (as divorce) in regard to us}}
\hadithdefcmd{muslim}{3689}{وَحَدَّثَنِي أَبُو الرَّبِيعِ الزَّهْرَانِيُّ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ زَكَرِيَّاءَ، حَدَّثَنَا الأَعْمَشُ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، وَعَنِ الأَعْمَشِ، عَنْ مُسْلِمٍ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، بِمِثْلِهِ‏.‏\hadithno{3689}\hadithtrans{A hadith like this has been transmitted on the authority of 'A'isha through another chain of narrators}}
\hadithdefcmd{muslim}{3690}{وَحَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا رَوْحُ بْنُ عُبَادَةَ، حَدَّثَنَا زَكَرِيَّاءُ بْنُ إِسْحَاقَ، حَدَّثَنَا أَبُو الزُّبَيْرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ دَخَلَ أَبُو بَكْرٍ يَسْتَأْذِنُ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَوَجَدَ النَّاسَ جُلُوسًا بِبَابِهِ لَمْ يُؤْذَنْ لأَحَدٍ مِنْهُمْ - قَالَ - فَأُذِنَ لأَبِي بَكْرٍ فَدَخَلَ ثُمَّ أَقْبَلَ عُمَرُ فَاسْتَأْذَنَ فَأُذِنَ لَهُ فَوَجَدَ النَّبِيَّ صلى الله عليه وسلم جَالِسًا حَوْلَهُ نِسَاؤُهُ وَاجِمًا سَاكِتًا - قَالَ - فَقَالَ لأَقُولَنَّ شَيْئًا أُضْحِكُ النَّبِيَّ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ لَوْ رَأَيْتَ بِنْتَ خَارِجَةَ سَأَلَتْنِي النَّفَقَةَ فَقُمْتُ إِلَيْهَا فَوَجَأْتُ عُنُقَهَا ‏.‏ فَضَحِكَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَقَالَ ‏"‏ هُنَّ حَوْلِي كَمَا تَرَى يَسْأَلْنَنِي النَّفَقَةَ ‏"‏ ‏.‏ فَقَامَ أَبُو بَكْرٍ إِلَى عَائِشَةَ يَجَأُ عُنُقَهَا فَقَامَ عُمَرُ إِلَى حَفْصَةَ يَجَأُ عُنُقَهَا كِلاَهُمَا يَقُولُ تَسْأَلْنَ رَسُولَ اللَّهِ صلى الله عليه وسلم مَا لَيْسَ عِنْدَهُ ‏.‏ فَقُلْنَ وَاللَّهِ لاَ نَسْأَلُ رَسُولَ اللَّهِ صلى الله عليه وسلم شَيْئًا أَبَدًا لَيْسَ عِنْدَهُ ثُمَّ اعْتَزَلَهُنَّ شَهْرًا أَوْ تِسْعًا وَعِشْرِينَ ثُمَّ نَزَلَتْ عَلَيْهِ هَذِهِ الآيَةُ ‏\{‏ يَا أَيُّهَا النَّبِيُّ قُلْ لأَزْوَاجِكَ‏\}‏ حَتَّى بَلَغَ ‏\{‏ لِلْمُحْسِنَاتِ مِنْكُنَّ أَجْرًا عَظِيمًا‏\}‏ قَالَ فَبَدَأَ بِعَائِشَةَ فَقَالَ ‏"‏ يَا عَائِشَةُ إِنِّي أُرِيدُ أَنْ أَعْرِضَ عَلَيْكَ أَمْرًا أُحِبُّ أَنْ لاَ تَعْجَلِي فِيهِ حَتَّى تَسْتَشِيرِي أَبَوَيْكِ ‏"‏ ‏.‏ قَالَتْ وَمَا هُوَ يَا رَسُولَ اللَّهِ فَتَلاَ عَلَيْهَا الآيَةَ قَالَتْ أَفِيكَ يَا رَسُولَ اللَّهِ أَسْتَشِيرُ أَبَوَىَّ بَلْ أَخْتَارُ اللَّهَ وَرَسُولَهُ وَالدَّارَ الآخِرَةَ وَأَسْأَلُكَ أَنْ لاَ تُخْبِرَ امْرَأَةً مِنْ نِسَائِكَ بِالَّذِي قُلْتُ ‏.‏ قَالَ ‏"‏ لاَ تَسْأَلُنِي امْرَأَةٌ مِنْهُنَّ إِلاَّ أَخْبَرْتُهَا إِنَّ اللَّهَ لَمْ يَبْعَثْنِي مُعَنِّتًا وَلاَ مُتَعَنِّتًا وَلَكِنْ بَعَثَنِي مُعَلِّمًا مُيَسِّرًا ‏"‏ ‏.‏\hadithno{3690}\hadithtrans{Jabir b. 'Abdullah (Allah be pleased with them) reported:Abu Bakr (Allah be pleased with him) came and sought permission to see Allah's Messenger (ﷺ). He found people sitting at his door and none amongst them had been granted permission, but it was granted to Abu Bakr and he went in. Then came 'Umar and he sought permission and it was granted to him, and he found Allah's Apostle (ﷺ) sitting sad and silent with his wives around him. He (Hadrat 'Umar) said: I would say something which would make the Prophet (ﷺ) laugh, so he said: Messenger of Allah, I wish you had seen (the treatment meted out to) the daughter ofKhadija when you asked me some money, and I got up and slapped her on her neck. Allah's Messenger (mav peace be upon him) laughed and said: They are around me as you see, asking for extra money. Abu Bakr (Allah be pleased with him) then got up went to 'A'isha (Allah be pleased with her) and slapped her on the neck, and 'Umar stood up before Hafsa and slapped her saying: You ask Allah's Messenger (ﷺ) which he does not possess. They said: By Allah, we do not ask Allah's Messenger (ﷺ) for anything he does not possess. Then he withdrew from them for a month or for twenty-nine days. Then this verse was revealed to him:" Prophet: Say to thy wives... for a mighty reward" (xxxiii. 28). He then went first to 'A'isha (Allah be pleased with her) and said: I want to propound something to you, 'A'isha, but wish no hasty reply before you consult your parents. She said: Messenger of Allah, what is that? He (the Holy Prophet) recited to her the verse, whereupon she said: Is it about you that I should consult my parents, Messenger of Allah? Nay, I choose Allah, His Messenger, and the Last Abode; but I ask you not to tell any of your wives what I have said He replied: Not one of them will ask me without my informing her. God did not send me to be harsh, or cause harm, but He has sent me to teach and make things easy}}
\hadithdefcmd{muslim}{3691}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا عُمَرُ بْنُ يُونُسَ الْحَنَفِيُّ، حَدَّثَنَا عِكْرِمَةُ بْنُ عَمَّارٍ، عَنْ سِمَاكٍ أَبِي زُمَيْلٍ، حَدَّثَنِي عَبْدُ اللَّهِ بْنُ عَبَّاسٍ، حَدَّثَنِي عُمَرُ بْنُ الْخَطَّابِ، قَالَ لَمَّا اعْتَزَلَ نَبِيُّ اللَّهِ صلى الله عليه وسلم نِسَاءَهُ - قَالَ - دَخَلْتُ الْمَسْجِدَ فَإِذَا النَّاسُ يَنْكُتُونَ بِالْحَصَى وَيَقُولُونَ طَلَّقَ رَسُولُ اللَّهِ صلى الله عليه وسلم نِسَاءَهُ وَذَلِكَ قَبْلَ أَنْ يُؤْمَرْنَ بِالْحِجَابِ فَقَالَ عُمَرُ فَقُلْتُ لأَعْلَمَنَّ ذَلِكَ الْيَوْمَ قَالَ فَدَخَلْتُ عَلَى عَائِشَةَ فَقُلْتُ يَا بِنْتَ أَبِي بَكْرٍ أَقَدْ بَلَغَ مِنْ شَأْنِكِ أَنْ تُؤْذِي رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَتْ مَا لِي وَمَا لَكَ يَا ابْنَ الْخَطَّابِ عَلَيْكَ بِعَيْبَتِكَ ‏.‏ قَالَ فَدَخَلْتُ عَلَى حَفْصَةَ بِنْتِ عُمَرَ فَقُلْتُ لَهَا يَا حَفْصَةُ أَقَدْ بَلَغَ مِنْ شَأْنِكِ أَنْ تُؤْذِي رَسُولَ اللَّهِ صلى الله عليه وسلم وَاللَّهِ لَقَدْ عَلِمْتِ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم لاَ يُحِبُّكِ ‏.‏ وَلَوْلاَ أَنَا لَطَلَّقَكِ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏ فَبَكَتْ أَشَدَّ الْبُكَاءِ فَقُلْتُ لَهَا أَيْنَ رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَتْ هُوَ فِي خِزَانَتِهِ فِي الْمَشْرُبَةِ ‏.‏ فَدَخَلْتُ فَإِذَا أَنَا بِرَبَاحٍ غُلاَمِ رَسُولِ اللَّهِ صلى الله عليه وسلم قَاعِدًا عَلَى أُسْكُفَّةِ الْمَشْرُبَةِ مُدَلٍّ رِجْلَيْهِ عَلَى نَقِيرٍ مِنْ خَشَبٍ وَهُوَ جِذْعٌ يَرْقَى عَلَيْهِ رَسُولُ اللَّهِ صلى الله عليه وسلم وَيَنْحَدِرُ فَنَادَيْتُ يَا رَبَاحُ اسْتَأْذِنْ لِي عِنْدَكَ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ فَنَظَرَ رَبَاحٌ إِلَى الْغُرْفَةِ ثُمَّ نَظَرَ إِلَىَّ فَلَمْ يَقُلْ شَيْئًا ثُمَّ قُلْتُ يَا رَبَاحُ اسْتَأْذِنْ لِي عِنْدَكَ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ فَنَظَرَ رَبَاحٌ إِلَى الْغُرْفَةِ ثُمَّ نَظَرَ إِلَىَّ فَلَمْ يَقُلْ شَيْئًا ثُمَّ رَفَعْتُ صَوْتِي فَقُلْتُ يَا رَبَاحُ اسْتَأْذِنْ لِي عِنْدَكَ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَإِنِّي أَظُنُّ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم ظَنَّ أَنِّي جِئْتُ مِنْ أَجْلِ حَفْصَةَ وَاللَّهِ لَئِنْ أَمَرَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم بِضَرْبِ عُنُقِهَا لأَضْرِبَنَّ عُنُقَهَا ‏.‏ وَرَفَعْتُ صَوْتِي فَأَوْمَأَ إِلَىَّ أَنِ ارْقَهْ فَدَخَلْتُ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم وَهُوَ مُضْطَجِعٌ عَلَى حَصِيرٍ فَجَلَسْتُ فَأَدْنَى عَلَيْهِ إِزَارَهُ وَلَيْسَ عَلَيْهِ غَيْرُهُ وَإِذَا الْحَصِيرُ قَدْ أَثَّرَ فِي جَنْبِهِ فَنَظَرْتُ بِبَصَرِي فِي خِزَانَةِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَإِذَا أَنَا بِقَبْضَةٍ مِنْ شَعِيرٍ نَحْوِ الصَّاعِ وَمِثْلِهَا قَرَظًا فِي نَاحِيَةِ الْغُرْفَةِ وَإِذَا أَفِيقٌ مُعَلَّقٌ - قَالَ - فَابْتَدَرَتْ عَيْنَاىَ قَالَ ‏"‏ مَا يُبْكِيكَ يَا ابْنَ الْخَطَّابِ ‏"‏ ‏.‏ قُلْتُ يَا نَبِيَّ اللَّهِ وَمَا لِي لاَ أَبْكِي وَهَذَا الْحَصِيرُ قَدْ أَثَّرَ فِي جَنْبِكَ وَهَذِهِ خِزَانَتُكَ لاَ أَرَى فِيهَا إِلاَّ مَا أَرَى وَذَاكَ قَيْصَرُ وَكِسْرَى فِي الثِّمَارِ وَالأَنْهَارِ وَأَنْتَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَصَفْوَتُهُ وَهَذِهِ خِزَانَتُكَ ‏.‏ فَقَالَ ‏"‏ يَا ابْنَ الْخَطَّابِ أَلاَ تَرْضَى أَنْ تَكُونَ لَنَا الآخِرَةُ وَلَهُمُ الدُّنْيَا ‏"‏ ‏.‏ قُلْتُ بَلَى - قَالَ - وَدَخَلْتُ عَلَيْهِ حِينَ دَخَلْتُ وَأَنَا أَرَى فِي وَجْهِهِ الْغَضَبَ فَقُلْتُ يَا رَسُولَ اللَّهِ مَا يَشُقُّ عَلَيْكَ مِنْ شَأْنِ النِّسَاءِ فَإِنْ كُنْتَ طَلَّقْتَهُنَّ فَإِنَّ اللَّهَ مَعَكَ وَمَلاَئِكَتَهُ وَجِبْرِيلَ وَمِيكَائِيلَ وَأَنَا وَأَبُو بَكْرٍ وَالْمُؤْمِنُونَ مَعَكَ وَقَلَّمَا تَكَلَّمْتُ وَأَحْمَدُ اللَّهَ بِكَلاَمٍ إِلاَّ رَجَوْتُ أَنْ يَكُونَ اللَّهُ يُصَدِّقُ قَوْلِي الَّذِي أَقُولُ وَنَزَلَتْ هَذِهِ الآيَةُ آيَةُ التَّخْيِيرِ ‏\{‏ عَسَى رَبُّهُ إِنْ طَلَّقَكُنَّ أَنْ يُبْدِلَهُ أَزْوَاجًا خَيْرًا مِنْكُنَّ‏\}‏ ‏\{‏ وَإِنْ تَظَاهَرَا عَلَيْهِ فَإِنَّ اللَّهَ هُوَ مَوْلاَهُ وَجِبْرِيلُ وَصَالِحُ الْمُؤْمِنِينَ وَالْمَلاَئِكَةُ بَعْدَ ذَلِكَ ظَهِيرٌ‏\}‏ وَكَانَتْ عَائِشَةُ بِنْتُ أَبِي بَكْرٍ وَحَفْصَةُ تَظَاهَرَانِ عَلَى سَائِرِ نِسَاءِ النَّبِيِّ صلى الله عليه وسلم فَقُلْتُ يَا رَسُولَ اللَّهِ أَطَلَّقْتَهُنَّ قَالَ ‏"‏ لاَ ‏"‏ ‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ إِنِّي دَخَلْتُ الْمَسْجِدَ وَالْمُسْلِمُونَ يَنْكُتُونَ بِالْحَصَى يَقُولُونَ طَلَّقَ رَسُولُ اللَّهِ صلى الله عليه وسلم نِسَاءَهُ أَفَأَنْزِلُ فَأُخْبِرَهُمْ أَنَّكَ لَمْ تُطَلِّقْهُنَّ قَالَ ‏"‏ نَعَمْ إِنْ شِئْتَ ‏"‏ ‏.‏ فَلَمْ أَزَلْ أُحَدِّثُهُ حَتَّى تَحَسَّرَ الْغَضَبُ عَنْ وَجْهِهِ وَحَتَّى كَشَرَ فَضَحِكَ وَكَانَ مِنْ أَحْسَنِ النَّاسِ ثَغْرًا ثُمَّ نَزَلَ نَبِيُّ اللَّهِ صلى الله عليه وسلم وَنَزَلْتُ فَنَزَلْتُ أَتَشَبَّثُ بِالْجِذْعِ وَنَزَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم كَأَنَّمَا يَمْشِي عَلَى الأَرْضِ مَا يَمَسُّهُ بِيَدِهِ فَقُلْتُ يَا رَسُولَ اللَّهِ إِنَّمَا كُنْتَ فِي الْغُرْفَةِ تِسْعَةً وَعِشْرِينَ ‏.‏ قَالَ ‏"‏ إِنَّ الشَّهْرَ يَكُونُ تِسْعًا وَعِشْرِينَ ‏"‏ ‏.‏ فقُمْتُ عَلَى بَابِ الْمَسْجِدِ فَنَادَيْتُ بِأَعْلَى صَوْتِي لَمْ يُطَلِّقْ رَسُولُ اللَّهِ صلى الله عليه وسلم نِسَاءَهُ ‏.‏ وَنَزَلَتْ هَذِهِ الآيَةُ ‏\{‏ وَإِذَا جَاءَهُمْ أَمْرٌ مِنَ الأَمْنِ أَوِ الْخَوْفِ أَذَاعُوا بِهِ وَلَوْ رَدُّوهُ إِلَى الرَّسُولِ وَإِلَى أُولِي الأَمْرِ مِنْهُمْ لَعَلِمَهُ الَّذِينَ يَسْتَنْبِطُونَهُ مِنْهُمْ‏\}‏ فَكُنْتُ أَنَا اسْتَنْبَطْتُ ذَلِكَ الأَمْرَ وَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ آيَةَ التَّخْيِيرِ ‏.‏\hadithno{3691}\hadithtrans{Umar b. al-Khattab (Allah be pleased with him) reported:When Allah's Apostle (ﷺ) kept himself away from his wives, I entered the mosque, and found people striking the ground with pebblesand saying: Allah's Messenger (ﷺ) has divorced his wives, and that was before they were commanded to observe seclusion 'Umar said to himself: I must find this (actual position) today. So I went to 'A'isha (Allah be pleased with her) and said (to her): Daughter of Abu Bakr, have you gone to the extent of giving trouble to Allah's Messenger (ﷺ)? Thereupon she said: Son of Khattab, you have nothing to do with me, and I have nothing to do with you. You should look to your own receptacle. He ('Umar) said: I visited Hafsa daughter of 'Umar, and said to her: Hafsa, the (news) has reached me that you cause Allah's Messenger (ﷺ) trouble. You know that Allah's Messenger (ﷺ) does not love you, and had I not been (your father) he would have divorced you. (On hearing this) she wept bitterly. I said to her: Where is Allah's Messenger (ﷺ)? Shesaid: He is in the attic room. I went in and found Rabah, the servant of Allah's Messenger (ﷺ), sitting on the thresholds of the window dangling his feet on the hollow wood of the date-palm with the help of which Allah's Messenger (ﷺ) climbed (to the apartment) and came down. I cried: 0 Rabah, seek permission for me from Allah's Messenger (way peace be upon him). Rabah cast a glance at the apartment and then looked toward me but said nothing. I again said: Rabah, seek permission for me from Allah's Messenger (ﷺ). Rabah looked towards the apartment and then cast a glance at me, but said nothig. I then raised my voice and said: 0 Rabah, seek permission for me from Allah's Messenger (ﷺ). I think that Allah's Messenger (ﷺ) is under the impression that I have come for the sake of Hafsa. By Allah, if Allah's Messenger (ﷺ) would command me to strike her neck, I would certainly strike her neck. I raised my voice and he pointed me to climb up (and get into his apartment). I visited Allah's Messenger (ﷺ), and he was lying on a mat. I sat down and he drew up his lower garment over him and he had nothing (else) over him, and that the mat had left its marks on his sides. I looked with my eyes in the store room of Allah's Messenger (ﷺ). I found only a handful of barley equal to one sa' and an equal quantity of the leaves of Mimosa Flava placed in the nook of the cell, and a semi-tanned leather bag hanging (in one side), and I was moved to tears (on seeing this extremely austere living of the Holy Piophet), and he said: Ibn Khattab, what wakes you weep? I said: Apostle of Allah, why should I not shed tears? This mat has left its marks on your sides and I do not see in your store room (except these few things) that I have seen; Ceasar and Closroes are leading their lives in plenty whereas you are Allah's Messenger. His chosen one, and that is your store! He said: Ibn Khattab, aren't you satisfied that for us (there should be the prosperity) of the Hereafter, and for them (there should be the prosperity of) this world? I said: Yes. And as I had entered I had seen the signs of anger on his face, and I therefore, said: Messenger of Allah, what trouble do you feel from your wives, and if youhave divorced them, verily Allah is with you, His angels, Gabriel, Mika'il, I and Abu Bakr and the believers are with you. And seldom I talked and (which I uttered on that day) I hoped that Allah would testify to my words that I uttered. And so the verse of option (Ayat al-Takhyir) was revealed. Maybe his Lord, if he divorce you, will give him in your place wives better than you..." (Ixv. 5). And if you back up one another against him, then surely Allah is his Patron, and Gabriel and the righteous believers, and the angels after that are the aidera (lvi. 4). And it was 'A'isha, daughter of Abu Bakr, and Hafsa who had prevailed upon all the wives of Allah's Prophet (way peace be upon him) for (pressing them for mote money). I said: Messenger of Allah, have you divorced them? He said: No. I said: Messenger of Allah, I entered the mosque and found the Muslims playing with pebbles (absorbed in thought) and saying: Allah's Messenger has divorced his wives. Should I get down and inform there that you have not divorced them? He said: Yes, if you so like. And I went on talking to him until I (found) the signs of anger disappeared on his face and (his seriousness was changed to a happy mood and as a result thereof) his face had the natural tranquillity upon it and he laughed and his teeth were the most charming (among the teeth) of all people. Then Allah's Apostle (ﷺ) climbed down and I also climbed down and catching hold of the wood of the palm-tree and Allah's Messenger (ﷺ) came down (with such ease) as if he was walking on the ground, not touching anything with his hand (to get support). I said: Messenger of Allah, you remained in your apartment for twenty-nine days. He said: (At times) the month consists of twenty-nine days. I stood at the door of the mosque and I called out at the top of my voice: The Messenger of Allah (ﷺ) has not divorced his wives (and it was on this occasion that this) verse was revealed:" And if any matter pertaining to peace or alarm comes within their ken, they broadcast it; whereas, if they would refer it to the Apostle and those who have been entrusted with authority amongst them, those of them who are engaged in obtaining intelligence would indeed know (what to do with) it" (iv 83). And it was I who understood this matter, and Allah revealed the verse pertaining to option (given to the Prophet (may peace be upon him in regard to the retaining or divorcing of his wives)}}
\hadithdefcmd{muslim}{3692}{حَدَّثَنَا هَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي سُلَيْمَانُ، - يَعْنِي ابْنَ بِلاَلٍ - أَخْبَرَنِي يَحْيَى، أَخْبَرَنِي عُبَيْدُ بْنُ حُنَيْنٍ، أَنَّهُ سَمِعَ عَبْدَ اللَّهِ بْنَ عَبَّاسٍ، يُحَدِّثُ قَالَ مَكَثْتُ سَنَةً وَأَنَا أُرِيدُ، أَنْ أَسْأَلَ، عُمَرَ بْنَ الْخَطَّابِ عَنْ آيَةٍ، فَمَا أَسْتَطِيعُ أَنْلَهُ حَتَّى خَرَجَ حَاجًّا فَخَرَجْتُ مَعَهُ فَلَمَّا رَجَعَ فَكُنَّا بِبَعْضِ الطَّرِيقِ عَدَلَ إِلَى الأَرَاكِ لِحَاجَةٍ لَهُ فَوَقَفْتُ لَهُ حَتَّى فَرَغَ ثُمَّ سِرْتُ مَعَهُ فَقُلْتُ يَا أَمِيرَ الْمُؤْمِنِينَ مَنِ اللَّتَانِ تَظَاهَرَتَا عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم مِنْ أَزْوَاجِهِ فَقَالَ تِلْكَ حَفْصَةُ وَعَائِشَةُ ‏.‏ قَالَ فَقُلْتُ لَهُ وَاللَّهِ إِنْ كُنْتُ لأُرِيدُ أَنْ أَسْأَلَكَ عَنْ هَذَا مُنْذُ سَنَةٍ فَمَا أَسْتَطِيعُ هَيْبَةً لَكَ ‏.‏ قَالَ فَلاَ تَفْعَلْ مَا ظَنَنْتَ أَنَّ عِنْدِي مِنْ عِلْمٍ فَسَلْنِي عَنْهُ فَإِنْ كُنْتُ أَعْلَمُهُ أَخْبَرْتُكَ - قَالَ - وَقَالَ عُمَرُ وَاللَّهِ إِنْ كُنَّا فِي الْجَاهِلِيَّةِ مَا نَعُدُّ لِلنِّسَاءِ أَمْرًا حَتَّى أَنْزَلَ اللَّهُ تَعَالَى فِيهِنَّ مَا أَنْزَلَ وَقَسَمَ لَهُنَّ مَا قَسَمَ قَالَ فَبَيْنَمَا أَنَا فِي أَمْرٍ أَأْتَمِرُهُ إِذْ قَالَتْ لِي امْرَأَتِي لَوْ صَنَعْتَ كَذَا وَكَذَا فَقُلْتُ لَهَا وَمَا لَكِ أَنْتِ وَلِمَا هَا هُنَا وَمَا تَكَلُّفُكِ فِي أَمْرٍ أُرِيدُهُ فَقَالَتْ لِي عَجَبًا لَكَ يَا ابْنَ الْخَطَّابِ مَا تُرِيدُ أَنْ تُرَاجَعَ أَنْتَ وَإِنَّ ابْنَتَكَ لَتُرَاجِعُ رَسُولَ اللَّهِ صلى الله عليه وسلم حَتَّى يَظَلَّ يَوْمَهُ غَضْبَانَ ‏.‏ قَالَ عُمَرُ فَآخُذُ رِدَائِي ثُمَّ أَخْرُجُ مَكَانِي حَتَّى أَدْخُلَ عَلَى حَفْصَةَ فَقُلْتُ لَهَا يَا بُنَيَّةُ إِنَّكِ لَتُرَاجِعِينَ رَسُولَ اللَّهِ صلى الله عليه وسلم حَتَّى يَظَلَّ يَوْمَهُ غَضْبَانَ ‏.‏ فَقَالَتْ حَفْصَةُ وَاللَّهِ إِنَّا لَنُرَاجِعُهُ ‏.‏ فَقُلْتُ تَعْلَمِينَ أَنِّي أُحَذِّرُكِ عُقُوبَةَ اللَّهِ وَغَضَبَ رَسُولِهِ يَا بُنَيَّةُ لاَ يَغُرَّنَّكِ هَذِهِ الَّتِي قَدْ أَعْجَبَهَا حُسْنُهَا وَحُبُّ رَسُولِ اللَّهِ صلى الله عليه وسلم إِيَّاهَا ‏.‏ ثُمَّ خَرَجْتُ حَتَّى أَدْخُلَ عَلَى أُمِّ سَلَمَةَ لِقَرَابَتِي مِنْهَا فَكَلَّمْتُهَا فَقَالَتْ لِي أُمُّ سَلَمَةَ عَجَبًا لَكَ يَا ابْنَ الْخَطَّابِ قَدْ دَخَلْتَ فِي كُلِّ شَىْءٍ حَتَّى تَبْتَغِي أَنْ تَدْخُلَ بَيْنَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَأَزْوَاجِهِ ‏.‏ قَالَ فَأَخَذَتْنِي أَخْذًا كَسَرَتْنِي عَنْ بَعْضِ مَا كُنْتُ أَجِدُ فَخَرَجْتُ مِنْ عِنْدِهَا وَكَانَ لِي صَاحِبٌ مِنَ الأَنْصَارِ إِذَا غِبْتُ أَتَانِي بِالْخَبَرِ وَإِذَا غَابَ كُنْتُ أَنَا آتِيهِ بِالْخَبَرِ وَنَحْنُ حِينَئِذٍ نَتَخَوَّفُ مَلِكًا مِنْ مُلُوكِ غَسَّانَ ذُكِرَ لَنَا أَنَّهُ يُرِيدُ أَنْ يَسِيرَ إِلَيْنَا فَقَدِ امْتَلأَتْ صُدُورُنَا مِنْهُ فَأَتَى صَاحِبِي الأَنْصَارِيُّ يَدُقُّ الْبَابَ وَقَالَ افْتَحِ افْتَحْ ‏.‏ فَقُلْتُ جَاءَ الْغَسَّانِيُّ فَقَالَ أَشَدُّ مِنْ ذَلِكَ اعْتَزَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَزْوَاجَهُ ‏.‏ فَقُلْتُ رَغِمَ أَنْفُ حَفْصَةَ وَعَائِشَةَ ‏.‏ ثُمَّ آخُذُ ثَوْبِي فَأَخْرُجُ حَتَّى جِئْتُ فَإِذَا رَسُولُ اللَّهِ صلى الله عليه وسلم فِي مَشْرُبَةٍ لَهُ يُرْتَقَى إِلَيْهَا بِعَجَلَةٍ وَغُلاَمٌ لِرَسُولِ اللَّهِ صلى الله عليه وسلم أَسْوَدُ عَلَى رَأْسِ الدَّرَجَةِ فَقُلْتُ هَذَا عُمَرُ ‏.‏ فَأُذِنَ لِي ‏.‏ قَالَ عُمَرُ فَقَصَصْتُ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم هَذَا الْحَدِيثَ فَلَمَّا بَلَغْتُ حَدِيثَ أُمِّ سَلَمَةَ تَبَسَّمَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَإِنَّهُ لَعَلَى حَصِيرٍ مَا بَيْنَهُ وَبَيْنَهُ شَىْءٌ وَتَحْتَ رَأْسِهِ وِسَادَةٌ مِنْ أَدَمٍ حَشْوُهَا لِيفٌ وَإِنَّ عِنْدَ رِجْلَيْهِ قَرَظًا مَضْبُورًا وَعِنْدَ رَأْسِهِ أُهُبًا مُعَلَّقَةً فَرَأَيْتُ أَثَرَ الْحَصِيرِ فِي جَنْبِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَبَكَيْتُ فَقَالَ ‏"‏ مَا يُبْكِيكَ ‏"‏ ‏.‏ فَقُلْتُ يَا رَسُولَ اللَّهِ إِنَّ كِسْرَى وَقَيْصَرَ فِيمَا هُمَا فِيهِ وَأَنْتَ رَسُولُ اللَّهِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَمَا تَرْضَى أَنْ تَكُونَ لَهُمَا الدُّنْيَا وَلَكَ الآخِرَةُ ‏"‏ ‏.‏\hadithno{3692}\hadithtrans{Abdullah b. Abbas (Allah be pleased with tlicm) reported:I intended to ask 'Umar b. al-Khattab (Allah be pleased with him) about a verse, but I waited for one year to ask him out of his fear, until he went out for Pilgrimage and I also accompanied him. As he came back and we were on the way he stepped aside towards an Arak tree to ease himself. I waited for him until he was free. I then walked along with him and said: Commander of the Faithful, who are the two among the wives of Allah's Messenger (ﷺ) who backed up one another (in their demand for extra money)? He said: They were Hafsa and 'A'isha (Allah be pleased with them). I said to him: It is for one year that I intended to ask you about this matter but I could not date so on account of the awe for you. He said: Don't do that. If you think that I have any knowledge, do ask me about that. And if I were to know that, I would inform you. He (the narrator) stated that 'Umar had said: By Allah, during the days of ignorance we had no regard for women until Allah the Exalt- ed revealed about them what He has revealed, and appointed (turn) for them what he appointed. He said: It so happened that I was thinking about some matter that my wife said: I wish you had done that and that. I said to her: It does not concern you and you should not feel disturbed in a matter which I intend to do. She said to me: How strange is it that you, O son of Khattab, do not like anyone to retort upon you, whereas your daughter retorts upon Allah's Messenger (may peace be upou him) until he spends the day in vexation. 'Umar said: I took hold of my cloak, then came out of my house until I visited Hafsa and said to her: O daughter, (I heard) that you retort upon Allah's Messenger (ﷺ) until he spends the day in vexation, whereupon Hafsa said: By Allah, we do retort upon him. I said: You should bear in mind, my daughter, that I warn you against the punishment of Allah and the wrath of His Messenger (ﷺ). You may not be misled by one whose beauty has fascinated her, and the love of Allah's Messenger (ﷺ) for her. I ('Umar) then visited Umm Salama because of my relationship with her and I talked to her. Umm Salama said to me: Umar b. al-Khattab, how strange is it that you meddle with every matter so much so that you are anxious to interfere between Allah's Messenger (ﷺ) and his wives, and this perturbed me so much that I refrained from saying what I had to say, so I came out of her apartment, and I had a friend from the Anar. When I had been absent (from the company of the Holy Prophet) he used to bring me the news and when he had been absent I used to bring him the news, and at that time we dreaded a king of Ghassan. It was mentioned to us that he intended to attack us, and our minds were haunted by him. My friend, the Ansari, came to me, and he knocked at the door and said: Open it, open it. I said: Has the Ghassani come? He said: (The matter is) more serious than that. The Messenger of Allah (ﷺ) has separated himself from his wives. I said: Let the nose of Hafsa and 'A'isha be besmeared with dust. I then took hold of my cloth and went out until I came and found Allah's Messenger (ﷺ) in his attic to which he climbed by means of a ladder made of date-palm, and the servant of Allah's Messenger (ﷺ) who was black had been sitting at the end of the ladder. I said: This is Umar. So permission was granted to me. I narrated this news to Allah's Messenger (ﷺ) and as I narrated the news concerning Umm Salama, Allah's Messenger (ﷺ) smiled. He was lying on the mat and there was nothing between him and that (mat), and under his head there was a pillow made of leather and it was stuffed with plam fibres and at his feet were lying a heap of sant tree (acacia niloctica, meant for dyeing) and near his head there was hanging a hide. And I saw the marks of the maton the side of Allah's Messenger (ﷺ), and so I wept. He said: What makes you weep? I said: Messenger of Allah, the Khusrau and the Ceasars (spendd their lives in) the midst of (luxuries), whereas you being Allah's Messenger (are leading your life in this poverty). Thereupon Allah's Messenger (ﷺ) said: Don't you like that they should have riches of their world, and you have the Hereafter}}
\hadithdefcmd{muslim}{3693}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَفَّانُ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، أَخْبَرَنِي يَحْيَى بْنُ، سَعِيدٍ عَنْ عُبَيْدِ بْنِ حُنَيْنٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ أَقْبَلْتُ مَعَ عُمَرَ حَتَّى إِذَا كُنَّا بِمَرِّ الظَّهْرَانِ ‏.‏ وَسَاقَ الْحَدِيثَ بِطُولِهِ كَنَحْوِ حَدِيثِ سُلَيْمَانَ بْنِ بِلاَلٍ غَيْرَ أَنَّهُ قَالَ قُلْتُ شَأْنُ الْمَرْأَتَيْنِ قَالَ حَفْصَةُ وَأُمُّ سَلَمَةَ ‏.‏ وَزَادَ فِيهِ وَأَتَيْتُ الْحُجَرَ فَإِذَا فِي كُلِّ بَيْتٍ بُكَاءٌ ‏.‏ وَزَادَ أَيْضًا وَكَانَ آلَى مِنْهُنَّ شَهْرًا فَلَمَّا كَانَ تِسْعًا وَعِشْرِينَ نَزَلَ إِلَيْهِنَّ ‏.‏\hadithno{3693}\hadithtrans{Ibn Abbas (Allah be pleased with them) said:I came along with Umar until we reached Marr al-Zahran (the name of a place), and the rest of the hadith is the same as narrated by Sulaiman b. Bilal (except with) the variation (of words) that I said: (What) about these two women? He said: They were Hafsa and Umm Salama. And he made this addition: I came to the apartments and in every apartment there was (the noise) of weeping. And this addition was also made: And he (the Holy Prophet) had taken an oath of remaining away from them for a month, and when twenty-nine days had passed, he visited them}}
\hadithdefcmd{muslim}{3694}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَزُهَيْرُ بْنُ حَرْبٍ، - وَاللَّفْظُ لأَبِي بَكْرٍ - قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ يَحْيَى بْنِ سَعِيدٍ، سَمِعَ عُبَيْدَ بْنَ حُنَيْنٍ، - وَهُوَ مَوْلَى الْعَبَّاسِ - قَالَ سَمِعْتُ ابْنَ عَبَّاسٍ، يَقُولُ كُنْتُ أُرِيدُ أَنْ أَسْأَلَ، عُمَرَ عَنِ الْمَرْأَتَيْنِ اللَّتَيْنِ تَظَاهَرَتَا عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَلَبِثْتُ سَنَةً مَا أَجِدُ لَهُ مَوْضِعًا حَتَّى صَحِبْتُهُ إِلَى مَكَّةَ فَلَمَّا كَانَ بِمَرِّ الظَّهْرَانِ ذَهَبَ يَقْضِي حَاجَتَهُ فَقَالَ أَدْرِكْنِي بِإِدَاوَةٍ مِنْ مَاءٍ فَأَتَيْتُهُ بِهَا فَلَمَّا قَضَى حَاجَتَهُ وَرَجَعَ ذَهَبْتُ أَصُبُّ عَلَيْهِ وَذَكَرْتُ فَقُلْتُ لَهُ يَا أَمِيرَ الْمُؤْمِنِينَ مَنِ الْمَرْأَتَانِ فَمَا قَضَيْتُ كَلاَمِي حَتَّى قَالَ عَائِشَةُ وَحَفْصَةُ ‏.‏\hadithno{3694}\hadithtrans{Ibn Abbas (Allah be pleased with them) is reported to have said:I intended to ask Umar about those two ladies who had pressed for (worldly riches) during the lifetime of the Prophet (ﷺ), and I kept waiting for one year, but found no suitable opportunity with him until I happened to accompany him to Mecca. And as he reached Marr al Zahran he went away to answer the call of nature, and he said (to me): Bring me a jug of water, and I took that to him. After having answered the call of nature, as he came back, I began to pour water (over his hands and feet), and I remembered (this event of separation of Allah's Apostle [may peace be upon him] from his wives). So I said to him: Commander of the Faithful, who are the two ladies (who had pressed the Prophet [may peace be upon him] for providing comforts of life) and I had not yet finished my talk when he said: They were 'A'isha and Hafsa}}
\hadithdefcmd{muslim}{3696}{وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ الْحَنْظَلِيُّ، وَمُحَمَّدُ بْنُ أَبِي عُمَرَ، - وَتَقَارَبَا فِي لَفْظِ الْحَدِيثِ - قَالَ ابْنُ أَبِي عُمَرَ حَدَّثَنَا وَقَالَ، إِسْحَاقُ أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي ثَوْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ لَمْ أَزَلْ حَرِيصًا أَنْأَسْأَلَ عُمَرَ عَنِ الْمَرْأَتَيْنِ مِنْ أَزْوَاجِ النَّبِيِّ صلى الله عليه وسلم اللَّتَيْنِ قَالَ اللَّهُ تَعَالَى ‏\{‏إِنْ تَتُوبَا إِلَى اللَّهِ فَقَدْ صَغَتْ قُلُوبُكُمَا‏\}‏ حَتَّى حَجَّ عُمَرُ وَحَجَجْتُ مَعَهُ فَلَمَّا كُنَّا بِبَعْضِ الطَّرِيقِ عَدَلَ عُمَرُ وَعَدَلْتُ مَعَهُ بِالإِدَاوَةِ فَتَبَرَّزَ ثُمَّ أَتَانِي فَسَكَبْتُ عَلَى يَدَيْهِ فَتَوَضَّأَ فَقُلْتُ يَا أَمِيرَ الْمُؤْمِنِينَ مَنِ الْمَرْأَتَانِ مِنْ أَزْوَاجِ النَّبِيِّ صلى الله عليه وسلم اللَّتَانِ قَالَ اللَّهُ عَزَّ وَجَلَّ لَهُمَا ‏\{‏ إِنْ تَتُوبَا إِلَى اللَّهِ فَقَدْ صَغَتْ قُلُوبُكُمَا‏\}‏ قَالَ عُمَرُ وَاعَجَبًا لَكَ يَا ابْنَ عَبَّاسٍ - قَالَ الزُّهْرِيُّ كَرِهَ وَاللَّهِ مَا سَأَلَهُ عَنْهُ وَلَمْ يَكْتُمْهُ - قَالَ هِيَ حَفْصَةُ وَعَائِشَةُ ‏.‏ ثُمَّ أَخَذَ يَسُوقُ الْحَدِيثَ قَالَ كُنَّا مَعْشَرَ قُرَيْشٍ قَوْمًا نَغْلِبُ النِّسَاءَ فَلَمَّا قَدِمْنَا الْمَدِينَةَ وَجَدْنَا قَوْمًا تَغْلِبُهُمْ نِسَاؤُهُمْ فَطَفِقَ نِسَاؤُنَا يَتَعَلَّمْنَ مِنْ نِسَائِهِمْ - قَالَ - وَكَانَ مَنْزِلِي فِي بَنِي أُمَيَّةَ بْنِ زَيْدٍ بِالْعَوَالِي فَتَغَضَّبْتُ يَوْمًا عَلَى امْرَأَتِي فَإِذَا هِيَ تُرَاجِعُنِي فَأَنْكَرْتُ أَنْ تُرَاجِعَنِي ‏.‏ فَقَالَتْ مَا تُنْكِرُ أَنْ أُرَاجِعَكَ فَوَاللَّهِ إِنَّ أَزْوَاجَ النَّبِيِّ صلى الله عليه وسلم لَيُرَاجِعْنَهُ وَتَهْجُرُهُ إِحْدَاهُنَّ الْيَوْمَ إِلَى اللَّيْلِ ‏.‏ فَانْطَلَقْتُ فَدَخَلْتُ عَلَى حَفْصَةَ فَقُلْتُ أَتُرَاجِعِينَ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَتْ نَعَمْ ‏.‏ فَقُلْتُ أَتَهْجُرُهُ إِحْدَاكُنَّ الْيَوْمَ إِلَى اللَّيْلِ قَالَتْ نَعَمْ ‏.‏ قُلْتُ قَدْ خَابَ مَنْ فَعَلَ ذَلِكَ مِنْكُنَّ وَخَسِرَ أَفَتَأْمَنُ إِحْدَاكُنَّ أَنْ يَغْضَبَ اللَّهُ عَلَيْهَا لِغَضَبِ رَسُولِهِ صلى الله عليه وسلم فَإِذَا هِيَ قَدْ هَلَكَتْ لاَ تُرَاجِعِي رَسُولَ اللَّهِ صلى الله عليه وسلم وَلاَ تَسْأَلِيهِ شَيْئًا وَسَلِينِي مَا بَدَا لَكِ وَلاَ يَغُرَّنَّكِ أَنْ كَانَتْ جَارَتُكِ هِيَ أَوْسَمَ وَأَحَبَّ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم مِنْكِ - يُرِيدُ عَائِشَةَ - قَالَ وَكَانَ لِي جَارٌ مِنَ الأَنْصَارِ فَكُنَّا نَتَنَاوَبُ النُّزُولَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَيَنْزِلُ يَوْمًا وَأَنْزِلُ يَوْمًا فَيَأْتِينِي بِخَبَرِ الْوَحْىِ وَغَيْرِهِ وَآتِيهِ بِمِثْلِ ذَلِكَ وَكُنَّا نَتَحَدَّثُ أَنَّ غَسَّانَ تُنْعِلُ الْخَيْلَ لِتَغْزُوَنَا فَنَزَلَ صَاحِبِي ثُمَّ أَتَانِي عِشَاءً فَضَرَبَ بَابِي ثُمَّ نَادَانِي فَخَرَجْتُ إِلَيْهِ فَقَالَ حَدَثَ أَمْرٌ عَظِيمٌ ‏.‏ قُلْتُ مَاذَا أَجَاءَتْ غَسَّانُ قَالَ لاَ بَلْ أَعْظَمُ مِنْ ذَلِكَ وَأَطْوَلُ طَلَّقَ النَّبِيُّ صلى الله عليه وسلم نِسَاءَهُ ‏.‏ فَقُلْتُ قَدْ خَابَتْ حَفْصَةُ وَخَسِرَتْ قَدْ كُنْتُ أَظُنُّ هَذَا كَائِنًا حَتَّى إِذَا صَلَّيْتُ الصُّبْحَ شَدَدْتُ عَلَىَّ ثِيَابِي ثُمَّ نَزَلْتُ فَدَخَلْتُ عَلَى حَفْصَةَ وَهْىَ تَبْكِي فَقُلْتُ أَطَلَّقَكُنَّ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَتْ لاَ أَدْرِي هَا هُوَ ذَا مُعْتَزِلٌ فِي هَذِهِ الْمَشْرُبَةِ ‏.‏ فَأَتَيْتُ غُلاَمًا لَهُ أَسْوَدَ فَقُلْتُ اسْتَأْذِنْ لِعُمَرَ ‏.‏ فَدَخَلَ ثُمَّ خَرَجَ إِلَىَّ فَقَالَ قَدْ ذَكَرْتُكَ لَهُ فَصَمَتَ فَانْطَلَقْتُ حَتَّى انْتَهَيْتُ إِلَى الْمِنْبَرِ فَجَلَسْتُ فَإِذَا عِنْدَهُ رَهْطٌ جُلُوسٌ يَبْكِي بَعْضُهُمْ فَجَلَسْتُ قَلِيلاً ثُمَّ غَلَبَنِي مَا أَجِدُ ثُمَّ أَتَيْتُ الْغُلاَمَ فَقُلْتُ اسْتَأْذِنْ لِعُمَرَ ‏.‏ فَدَخَلَ ثُمَّ خَرَجَ إِلَىَّ ‏.‏ فَقَالَ قَدْ ذَكَرْتُكَ لَهُ فَصَمَتَ ‏.‏ فَوَلَّيْتُ مُدْبِرًا فَإِذَا الْغُلاَمُ يَدْعُونِي فَقَالَ ادْخُلْ فَقَدْ أَذِنَ لَكَ فَدَخَلْتُ فَسَلَّمْتُ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَإِذَا هُوَ مُتَّكِئٌ عَلَى رَمْلِ حَصِيرٍ قَدْ أَثَّرَ فِي جَنْبِهِ فَقُلْتُ أَطَلَّقْتَ يَا رَسُولَ اللَّهِ نِسَاءَكَ فَرَفَعَ رَأْسَهُ إِلَىَّ وَقَالَ ‏"‏ لاَ ‏"‏ ‏.‏ فَقُلْتُ اللَّهُ أَكْبَرُ لَوْ رَأَيْتَنَا يَا رَسُولَ اللَّهِ وَكُنَّا مَعْشَرَ قُرَيْشٍ قَوْمًا نَغْلِبُ النِّسَاءَ فَلَمَّا قَدِمْنَا الْمَدِينَةَ وَجَدْنَا قَوْمًا تَغْلِبُهُمْ نِسَاؤُهُمْ فَطَفِقَ نِسَاؤُنَا يَتَعَلَّمْنَ مِنْ نِسَائِهِمْ فَتَغَضَّبْتُ عَلَى امْرَأَتِي يَوْمًا فَإِذَا هِيَ تُرَاجِعُنِي فَأَنْكَرْتُ أَنْ تُرَاجِعَنِي ‏.‏ فَقَالَتْ مَا تُنْكِرُ أَنْ أُرَاجِعَكَ فَوَاللَّهِ إِنَّ أَزْوَاجَ النَّبِيِّ صلى الله عليه وسلم لَيُرَاجِعْنَهُ وَتَهْجُرُهُ إِحْدَاهُنَّ الْيَوْمَ إِلَى اللَّيْلِ ‏.‏ فَقُلْتُ قَدْ خَابَ مَنْ فَعَلَ ذَلِكَ مِنْهُنَّ وَخَسِرَ أَفَتَأْمَنُ إِحْدَاهُنَّ أَنْ يَغْضَبَ اللَّهُ عَلَيْهَا لِغَضَبِ رَسُولِهِ صلى الله عليه وسلم فَإِذَا هِيَ قَدْ هَلَكَتْ فَتَبَسَّمَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقُلْتُ يَا رَسُولَ اللَّهِ قَدْ دَخَلْتُ عَلَى حَفْصَةَ فَقُلْتُ لاَ يَغُرَّنَّكِ أَنْ كَانَتْ جَارَتُكِ هِيَ أَوْسَمُ مِنْكِ وَأَحَبُّ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم مِنْكِ ‏.‏ فَتَبَسَّمَ أُخْرَى فَقُلْتُ أَسْتَأْنِسُ يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ نَعَمْ ‏"‏ ‏.‏ فَجَلَسْتُ فَرَفَعْتُ رَأْسِي فِي الْبَيْتِ فَوَاللَّهِ مَا رَأَيْتُ فِيهِ شَيْئًا يَرُدُّ الْبَصَرَ إِلاَّ أُهُبًا ثَلاَثَةً فَقُلْتُ ادْعُ اللَّهَ يَا رَسُولَ اللَّهِ أَنْ يُوَسِّعَ عَلَى أُمَّتِكَ فَقَدْ وَسَّعَ عَلَى فَارِسَ وَالرُّومِ وَهُمْ لاَ يَعْبُدُونَ اللَّهَ فَاسْتَوَى جَالِسًا ثُمَّ قَالَ ‏"‏ أَفِي شَكٍّ أَنْتَ يَا ابْنَ الْخَطَّابِ أُولَئِكَ قَوْمٌ عُجِّلَتْ لَهُمْ طَيِّبَاتُهُمْ فِي الْحَيَاةِ الدُّنْيَا ‏"‏ ‏.‏ فَقُلْتُ اسْتَغْفِرْ لِي يَا رَسُولَ اللَّهِ ‏.‏ وَكَانَ أَقْسَمَ أَنْ لاَ يَدْخُلَ عَلَيْهِنَّ شَهْرًا مِنْ شِدَّةِ مَوْجِدَتِهِ عَلَيْهِنَّ ‏.‏ حَتَّى عَاتَبَهُ اللَّهُ عَزَّ وَجَلَّ ‏.‏ قَالَ الزُّهْرِيُّ فَأَخْبَرَنِي عُرْوَةُ، عَنْ عَائِشَةَ، قَالَتْ لَمَّا مَضَى تِسْعٌ وَعِشْرُونَ لَيْلَةً دَخَلَ عَلَىَّ رَسُولُ اللَّهِ صلى الله عليه وسلم بَدَأَ بِي فَقُلْتُ يَا رَسُولَ اللَّهِ إِنَّكَ أَقْسَمْتَ أَنْ لاَ تَدْخُلَ عَلَيْنَا شَهْرًا وَإِنَّكَ دَخَلْتَ مِنْ تِسْعٍ وَعِشْرِينَ أَعُدُّهُنَّ ‏.‏ فَقَالَ ‏"‏ إِنَّ الشَّهْرَ تِسْعٌ وَعِشْرُونَ - ثُمَّ قَالَ - يَا عَائِشَةُ إِنِّي ذَاكِرٌ لَكِ أَمْرًا فَلاَ عَلَيْكِ أَنْ لاَ تَعْجَلِي فِيهِ حَتَّى تَسْتَأْمِرِي أَبَوَيْكِ ‏"‏ ‏.‏ ثُمَّ قَرَأَ عَلَىَّ الآيَةَ ‏\{‏ يَا أَيُّهَا النَّبِيُّ قُلْ لأَزْوَاجِكَ‏\}‏ حَتَّى بَلَغَ ‏\{‏ أَجْرًا عَظِيمًا‏\}‏ قَالَتْ عَائِشَةُ قَدْ عَلِمَ وَاللَّهِ أَنَّ أَبَوَىَّ لَمْ يَكُونَا لِيَأْمُرَانِي بِفِرَاقِهِ قَالَتْ فَقُلْتُ أَوَفِي هَذَا أَسْتَأْمِرُ أَبَوَىَّ فَإِنِّي أُرِيدُ اللَّهَ وَرَسُولَهُ وَالدَّارَ الآخِرَةَ ‏.‏ قَالَ مَعْمَرٌ فَأَخْبَرَنِي أَيُّوبُ أَنَّ عَائِشَةَ قَالَتْ لاَ تُخْبِرْ نِسَاءَكَ أَنِّي اخْتَرْتُكَ فَقَالَ لَهَا النَّبِيُّ صلى الله عليه وسلم ‏"‏ إِنَّ اللَّهَ أَرْسَلَنِي مُبَلِّغًا وَلَمْ يُرْسِلْنِي مُتَعَنِّتًا ‏"‏ ‏.‏ قَالَ قَتَادَةُ صَغَتْ قُلُوبُكُمَا مَالَتْ قُلُوبُكُمَا‏.‏\hadithno{3696}\hadithtrans{Ibn 'Abbas (Allah be pleased with them) reported. I had always been anxious to ask 'Umar (Allah be pleased with him) about the two ladies amongst the wives of Allah's Prophet (may peace be upon Lim) about whom Allah, the Exalted, said:" If you both turn in repentance to Allah, then indeed your hearts are inclined (to this)" (Ixvi. 4), until 'Umar (Allah be pleased with him) set out for Hajj and I also went along with him. And as we were going along a path, 'Umar (Allah be pleased with hiyn) went aside and I also went aside with him with a jug (of water). He answered the call of nature, and then came to me and I poured water over his hands and he performed ablution I said: Commander of the Faithful, who are the two ladies amongst the wives of Allah's Prophet (ﷺ) about whom Allah, the Exalted and Majestic, said: 'If you both turn to Allah in repentance, then indeed your heart are inclined to it"? 'Umar (Allah he pleased with him) said: How strange is it for you, Ibn 'Abbas! (Zuhri said: By Allah, he disliked what he asked about, but did not keep it a secret.) He ('Umar) said: They are Hafsa and 'A'isha; and he then began to narrate the hadith and said: We were such people among the Quraish who dominated women, and as we reached Medina we found there people who were dominated by their women, and our women began to learn (the habits) of their women. He further said: And my house was situated in the suburb of Aledina in the tribe of Banu Umayya b. Zaid. One day I became angry with my wife and she retorted upon me. I did not like that she should retort upon me. She said: You disapprove of my retorting upon you By Allah, the wives of Allah's Apostle (ﷺ) retort upon him, and one of them detaches herself from him for the day until the night. So I ('Umar) went out and visited Hafsa and said: Do you retort upon Allah's Messenger (ﷺ)? She said: Yes. I said; Does any one of you detach herself from him from the day to the night? She said: Yes. He said: She who did like it amongst you in fact failed and incurred loss. Does everyone amongst you not fear the wrath of Allah upon her due to the wrath of His Messenger (ﷺ), and (as a result thereof) she may perish? So do not retort upon Allah's Messenger (ﷺ) and do not ask him for anything, but ask me that which you desire, (and the frank behaviour) of your companion may not mislead you, if she is more graceful and is dearer to Allah's Messenger (ﷺ) than you (meaning 'A'isha) (Allah be pleased with her). He (Hadrat 'Umar further) said: I had a compalaion from the Ansar and, we used to remain in the company of the Messenger (ﷺ) turn by turn. He remained there for a day while I remained there on the other day, and he brought me the news about the revelation and other (matter), and I brought him (the news) like this. And we discussed that the Ghassanids were shoeing the horses in order to attack us. Id y companion once attended (the Apostle). and then came to me at night and knocked at my door and called me, and I came out to him, and he said: A matter of great importance has happened. I said: What is that? Have the Ghassanids come? He said: No, but even more serious and more significant than that: the Prophet (ﷺ) has divorced his wives. I said: Hafsa has failed and has incurred loss. and I feared that it would happen. When it was dawn I observed the dawn prayer and dressed myself, and then came there (in the house of the Holy Prophet) and visited Hafsa, and she was weeping. I said: Has Allah's Messenger (ﷺ) divorced you (all)? She said: I do not know. He has, however, separated himself in his attic. I came to a black servant and said to him: Seek permission for 'Umar. He went in and then came to me and said: I made mention of you to him, but he kept quiet. I then went to the pulpit and sat there, and there was a group of people sitting by it and some of then were weeping. I sat there for some time, until I was overpowered (by that very idea) which was in my mind. I then came back to the boy and said to him: Seek permission for Umar. He went in and came to me and said: I made mention of you to him but he kept quiet. I was about to turn back when the boy called me and said: Go in; permission has been granted to you. I went in and greeted Allah's Messenger (ﷺ) and he was reclining against the couch of mat and it had left its marks upon his side. I said: Messenger of Allah, have you divorced your wives? He raised his head towards me and said: No. I said: Allah is the Greatest. Messenger of Allah, I wish if you had seen how we the people of Quraish had domination over women but when we came to Medina we found people whom their women dominated. So our women began to learn from their women. One dily I became angry with my wife and she began to retort upon me. I did not approve that she should retort upon me. She said: You do not like that I should retort upon you, but, by Allah. the wives of Allah's Apostle (ﷺ) retort upon him and any one of them separates herself from him for a day until night. I said: He who did that amongst them in fact failed and incurred loss. Does any of them feel sate from the wrath of Allahupon her due to the wrath of Allah's Messenger (ﷺ), and she has certainly perished. Allah's Messtnger (ﷺ) smiled, I said: Messenger of Allah, I visited Hafsa and said: (The behaviour) of your companion ('A'isha) may not mislead you, If she is more graceful than you and is dearer to Allah's Messenger (ﷺ) than you. Allah's Messenger (ﷺ) smiled for the second time. I said: Allah's Messenger, way I talk to you about agreeable things? He said: Yes. I sat down and lifted my head (to see things) in the house and, by Allah, I did not see anything significant besides three hides. I said: Messenger of Allah, supplicate the Lord that He should make (life) prosperous for your Ummah as He has made plentiful for the people of Persia and Rome (in spite of the fact) that they do no, worship Allah, the Exalted and Majestic, whereupon he (Allah's Messenger) sat up an I then said: Ibn Khattab, do you doubt that they are a nation whom their nice things have been given immediately in the life of this world. I said: Allah's Messenger! seek pardon for me. And he (Allah's Messenger) had taken an oath that he would not visit them for a month due to extreme annoyance with them until Allah showed His displeasure to him (Allah's Messenger). Zuhri said: 'Urwa informed me that 'A'Isha (Allah be pleased with her) said: When twenty-nine nights were over, Allah's Messenger (ﷺ) visited me, and he began (his visit) with me. I said: Messenger of Allah, you had taken an oath that you would not visit us for a month, while you have visited after I have counted only twenty-nine (nights). Thereupon he said: The month may also be of twenty-nine (days). He then said: 'A'isha, I am going to talk to you about a matter, and you should not be hasty in it (and do not give your final decision) until you have consulted your parents. He then recited this verse to me:" O Prophet, say to your wives" till he reached" mighty reward" (xxxiii. 28). 'A'isha (Allah be pleased with her) said: By Allah, he knew that my parents would not allow me to separate from him. I said: Is there any need to consult my parents in this matter? I in fact choose Allah and His Messenger (ﷺ) and the abode in the Hereafter. Ma'mar said: Ayyub reported to me that 'A'isha said: Don't inform your wives that I have chosen you, whereupon Allah's Apostle (ﷺ) said: Verily Allah has sent me as a conveyer of message, and He has not sent me as a source of hardship (to others). Qatada said:" Saghat qulubukum" means" Your hearts have inclined}}
\hadithdefcmd{muslim}{3697}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ عَبْدِ اللَّهِ بْنِ يَزِيدَ، مَوْلَى الأَسْوَدِ بْنِ سُفْيَانَ عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ فَاطِمَةَ بِنْتِ قَيْسٍ، أَنَّ أَبَا عَمْرِو بْنَ حَفْصٍ، طَلَّقَهَا الْبَتَّةَ وَهُوَ غَائِبٌ فَأَرْسَلَ إِلَيْهَا وَكِيلُهُ بِشَعِيرٍ فَسَخِطَتْهُ فَقَالَ وَاللَّهِ مَا لَكِ عَلَيْنَا مِنْ شَىْءٍ ‏.‏ فَجَاءَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم فَذَكَرَتْ ذَلِكَ لَهُ فَقَالَ ‏"‏ لَيْسَ لَكِ عَلَيْهِ نَفَقَةٌ ‏"‏ ‏.‏ فَأَمَرَهَا أَنْ تَعْتَدَّ فِي بَيْتِ أُمِّ شَرِيكٍ ثُمَّ قَالَ ‏"‏ تِلْكَ امْرَأَةٌ يَغْشَاهَا أَصْحَابِي اعْتَدِّي عِنْدَ ابْنِ أُمِّ مَكْتُومٍ فَإِنَّهُ رَجُلٌ أَعْمَى تَضَعِينَ ثِيَابَكِ فَإِذَا حَلَلْتِ فَآذِنِينِي ‏"‏ ‏.‏ قَالَتْ فَلَمَّا حَلَلْتُ ذَكَرْتُ لَهُ أَنَّ مُعَاوِيَةَ بْنَ أَبِي سُفْيَانَ وَأَبَا جَهْمٍ خَطَبَانِي ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَمَّا أَبُو جَهْمٍ فَلاَ يَضَعُ عَصَاهُ عَنْ عَاتَقِهِ وَأَمَّا مُعَاوِيَةُ فَصُعْلُوكٌ لاَ مَالَ لَهُ انْكِحِي أُسَامَةَ بْنَ زَيْدٍ ‏"‏ ‏.‏ فَكَرِهْتُهُ ثُمَّ قَالَ ‏"‏ انْكِحِي أُسَامَةَ ‏"‏ ‏.‏ فَنَكَحْتُهُ فَجَعَلَ اللَّهُ فِيهِ خَيْرًا وَاغْتَبَطْتُ بِهِ ‏.‏\hadithno{3697}\hadithtrans{Fatima bint Qais reported that Abu 'Amr b. Hafs divorced her absolutely when he was away from home, and he sent his agent to her with some barley. She was displeased with him and when he said:I swear by Allah that you have no claim on us. she went to Allah's Messenger (ﷺ) and mentioned that to him. He said: There is no maintenance due to you from him, and he commanded her to spend the 'Idda in the house of Umm Sharik, but then said: That is a woman whom my companions visit. So better spend this period in the house of Ibn Umm Maktum, for he is a blind man and yon can put off your garments. And when the 'Idda is over, inform me. She said: When my period of 'Idda was over, I mentioned to him that Mu'awiya b. Abu Sufyan and Jahm had sent proposal of marriage to me, whereupon Allah's Messenger (ﷺ) said: As for Abu Jahm, he does not put down his staff from his shoulder, and as for Mu'awiya, he is a poor man having no property; marry Usama b. Zaid. I objected to him, but he again said: Marry Usama; so I married him. Allah blessed there in and I was envied (by others)}}
\hadithdefcmd{muslim}{3698}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا عَبْدُ الْعَزِيزِ، - يَعْنِي ابْنَ أَبِي حَازِمٍ وَقَالَ قُتَيْبَةُ أَيْضًا حَدَّثَنَا يَعْقُوبُ، - يَعْنِي ابْنَ عَبْدِ الرَّحْمَنِ الْقَارِيَّ - كِلاَهُمَا عَنْ أَبِي حَازِمٍ، عَنْ أَبِي، سَلَمَةَ عَنْ فَاطِمَةَ بِنْتِ قَيْسٍ، أَنَّهُ طَلَّقَهَا زَوْجُهَا فِي عَهْدِ النَّبِيِّ صلى الله عليه وسلم وَكَانَ أَنْفَقَ عَلَيْهَا نَفَقَةَ دُونٍ فَلَمَّا رَأَتْ ذَلِكَ قَالَتْ وَاللَّهِ لأُعْلِمَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم فَإِذَا كَانَ لِي نَفَقَةٌ أَخَذْتُ الَّذِي يُصْلِحُنِي وَإِنْ لَمْ تَكُنْ لِي نَفَقَةٌ لَمْ آخُذْ مِنْهُ شَيْئًا قَالَتْ فَذَكَرْتُ ذَلِكَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ لاَ نَفَقَةَ لَكِ وَلاَ سُكْنَى ‏"‏ ‏.‏\hadithno{3698}\hadithtrans{Fatima bint Qais reported that her husband divorced her during the life time of Allah's Prophet (ﷺ) and gave her a meagre maintenance allowance. When she saw that, she said:By Allah, I will inform Allah's Messenger (ﷺ), and if maintenance allowance is due to me then I will accept that which will suffice me, and if it is not due to me, I will not accept anything from him. She said: I made a mention of that to Allah's Messenger (ﷺ) and he said: There is neither maintenance allowance for you nor lodging}}
\hadithdefcmd{muslim}{3699}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، عَنْ عِمْرَانَ بْنِ أَبِي أَنَسٍ، عَنْ أَبِي سَلَمَةَ، أَنَّهُ قَالَ سَأَلْتُ فَاطِمَةَ بِنْتَ قَيْسٍ فَأَخْبَرَتْنِي أَنَّ زَوْجَهَا الْمَخْزُومِيَّ طَلَّقَهَا فَأَبَى أَنْ يُنْفِقَ عَلَيْهَا فَجَاءَتْ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَأَخْبَرَتْهُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ نَفَقَةَ لَكِ فَانْتَقِلِي فَاذْهَبِي إِلَى ابْنِ أُمِّ مَكْتُومٍ فَكُونِي عِنْدَهُ فَإِنَّهُ رَجُلٌ أَعْمَى تَضَعِينَ ثِيَابَكِ عِنْدَهُ ‏"‏ ‏.‏\hadithno{3699}\hadithtrans{Fatima bint Qais reported that her husband al-Makhzulmi divorced her and refused to pay her maintenance allowance. So she came to Allah's Messenger (may peace he upon him) and informed him, whereupon he said:There is no maintenance allowance for you, and you better go to the house of Ibn Umm Maktum and live with him for he is a blind man and you can put off your clothes in his house (i. e. you shall not face much difficulty in observing purdah there)}}
\hadithdefcmd{muslim}{3700}{وَحَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا حُسَيْنُ بْنُ مُحَمَّدٍ، حَدَّثَنَا شَيْبَانُ، عَنْ يَحْيَى، - وَهُوَ ابْنُ أَبِي كَثِيرٍ - أَخْبَرَنِي أَبُو سَلَمَةَ، أَنَّ فَاطِمَةَ بِنْتَ قَيْسٍ، أُخْتَ الضَّحَّاكِ بْنِ قَيْسٍ أَخْبَرَتْهُ أَنَّ أَبَا حَفْصِ بْنَ الْمُغِيرَةِ الْمَخْزُومِيَّ طَلَّقَهَا ثَلاَثًا ثُمَّ انْطَلَقَ إِلَى الْيَمَنِ فَقَالَ لَهَا أَهْلُهُ لَيْسَ لَكِ عَلَيْنَا نَفَقَةٌ ‏.‏ فَانْطَلَقَ خَالِدُ بْنُ الْوَلِيدِ فِي نَفَرٍ فَأَتَوْا رَسُولَ اللَّهِ صلى الله عليه وسلم فِي بَيْتِ مَيْمُونَةَ فَقَالُوا إِنَّ أَبَا حَفْصٍ طَلَّقَ امْرَأَتَهُ ثَلاَثًا فَهَلْ لَهَا مِنْ نَفَقَةٍ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لَيْسَتْ لَهَا نَفَقَةٌ وَعَلَيْهَا الْعِدَّةُ ‏"‏ ‏.‏ وَأَرْسَلَ إِلَيْهَا ‏"‏ أَنْ لاَ تَسْبِقِينِي بِنَفْسِكِ ‏"‏ ‏.‏ وَأَمَرَهَا أَنْ تَنْتَقِلَ إِلَى أُمِّ شَرِيكٍ ثُمَّ أَرْسَلَ إِلَيْهَا ‏"‏ أَنَّ أُمَّ شَرِيكٍ يَأْتِيهَا الْمُهَاجِرُونَ الأَوَّلُونَ فَانْطَلِقِي إِلَى ابْنِ أُمِّ مَكْتُومٍ الأَعْمَى فَإِنَّكِ إِذَا وَضَعْتِ خِمَارَكِ لَمْ يَرَكِ ‏"‏ ‏.‏ فَانْطَلَقَتْ إِلَيْهِ فَلَمَّا مَضَتْ عِدَّتُهَا أَنْكَحَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم أُسَامَةَ بْنَ زَيْدِ بْنِ حَارِثَةَ\hadithno{3700}\hadithtrans{Abu Salama reported that Fatima bint Qais, the sister of al-Dahhak b. Qais informed him that Abu Hafs b. Mughira al-Makhzumi divorced her three times and then he proceeded on to the Yemen. The members of his family said to her:There is no maintenance allowance due to you from us. Khalid b. Walid along with a group of persons visited Allah's Messenger (ﷺ) in the house of Maimuna and they said: Abu Hafs has divorced his wife with three pronouncements; is there any maintenance allowance due to her? Thereupon Allah's Messenger (ﷺ) said: No maintenance allowance is due to her, but she is required to spend the 'Idda; and he sent her the message that she should not be hasty in making a decision about herself and commanded her to move to the house of Umm Sharik, and then sent her the message that as the first immigrants (frequently) visit the house of Umm Sharik, she should better go to the house of Ibn Umm Maktum, the blind, (and further said: In case you put off your head-dress, he (Ibn Umm Makhtum) will not see you. So she went to his house, and when the 'Idda was over, Allah's Messenger (ﷺ) married her to Usama b. Zaid b. Haritha}}
\hadithdefcmd{muslim}{3701}{حَدَّثَنَا يَحْيَى بْنُ أَيُّوبَ، وَقُتَيْبَةُ بْنُ سَعِيدٍ، وَابْنُ، حُجْرٍ قَالُوا حَدَّثَنَا إِسْمَاعِيلُ، - يَعْنُونَ ابْنَ جَعْفَرٍ - عَنْ مُحَمَّدِ بْنِ عَمْرٍو، عَنْ أَبِي سَلَمَةَ، عَنْ فَاطِمَةَ بِنْتِ قَيْسٍ، ح وَحَدَّثَنَاهُ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، حَدَّثَنَا مُحَمَّدُ بْنُ عَمْرٍو، حَدَّثَنَا أَبُو سَلَمَةَ، عَنْ فَاطِمَةَ بِنْتِ قَيْسٍ، قَالَ كَتَبْتُ ذَلِكَ مِنْ فِيهَا كِتَابًا قَالَتْ كُنْتُ عِنْدَ رَجُلٍ مِنْ بَنِي مَخْزُومٍ فَطَلَّقَنِي الْبَتَّةَ فَأَرْسَلْتُ إِلَى أَهْلِهِ أَبْتَغِي النَّفَقَةَ ‏.‏ وَاقْتَصُّوا الْحَدِيثَ بِمَعْنَى حَدِيثِ يَحْيَى بْنِ أَبِي كَثِيرٍ عَنْ أَبِي سَلَمَةَ ‏.‏ غَيْرَ أَنَّ فِي حَدِيثِ مُحَمَّدِ بْنِ عَمْرٍو ‏ "‏ لاَ تَفُوتِينَا بِنَفْسِكِ ‏"‏ ‏.‏\hadithno{3701}\hadithtrans{Fatima bint Qais reported:I had been married to a person from Banu Makhzum and he divorced me with irrevocable divorce. I sent a message to his family asking for maintenance allowance, and the rest of the hadith has been transmitted with a slight change of words}}
\hadithdefcmd{muslim}{3702}{حَدَّثَنَا حَسَنُ بْنُ عَلِيٍّ الْحُلْوَانِيُّ، وَعَبْدُ بْنُ حُمَيْدٍ، جَمِيعًا عَنْ يَعْقُوبَ بْنِ إِبْرَاهِيمَ، بْنِ سَعْدٍ حَدَّثَنَا أَبِي، عَنْ صَالِحٍ، عَنِ ابْنِ شِهَابٍ، أَنَّ أَبَا سَلَمَةَ بْنَ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ، أَخْبَرَهُ أَنَّ فَاطِمَةَ بِنْتَ قَيْسٍ أَخْبَرَتْهُ أَنَّهَا، كَانَتْ تَحْتَ أَبِي عَمْرِو بْنِ حَفْصِ بْنِ الْمُغِيرَةِ فَطَلَّقَهَا آخِرَ ثَلاَثِ تَطْلِيقَاتٍ فَزَعَمَتْ أَنَّهَا جَاءَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم تَسْتَفْتِيهِ فِي خُرُوجِهَا مِنْ بَيْتِهَا فَأَمَرَهَا أَنْ تَنْتَقِلَ إِلَى ابْنِ أُمِّ مَكْتُومٍ الأَعْمَى فَأَبَى مَرْوَانُ أَنْ يُصَدِّقَهُ فِي خُرُوجِ الْمُطَلَّقَةِ مِنْ بَيْتِهَا وَقَالَ عُرْوَةُ إِنَّ عَائِشَةَ أَنْكَرَتْ ذَلِكَ عَلَى فَاطِمَةَ بِنْتِ قَيْسٍ.‏\hadithno{3702}\hadithtrans{Fatima bint Qais (Allah be pleased with her) reported that she had been married to Abu 'Amr b. Hafs b. al-Mughira and he divorced her with three pronouncements. She stated that she went to Allah's Messenger (ﷺ) asking him about abandoning that house. He commanded her to move to the house of Ibn Umm Maktum, the blind. Marwan refused to testify the divorced woman abandoning her house (before the 'Idda was over). 'Urwa said that 'A'isha objected to (the words of) Fatima bint Qais}}
\hadithdefcmd{muslim}{3703}{وَحَدَّثَنِيهِ مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا حُجَيْنٌ، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، بِهَذَا الإِسْنَادِ مِثْلَهُ مَعَ قَوْلِ عُرْوَةَ إِنَّ عَائِشَةَ أَنْكَرَتْ ذَلِكَ عَلَى فَاطِمَةَ ‏.‏\hadithno{3703}\hadithtrans{This hadith has been transmitted through another chain of narrators}}
\hadithdefcmd{muslim}{3704}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَعَبْدُ بْنُ حُمَيْدٍ، - وَاللَّفْظُ لِعَبْدٍ - قَالاَ أَخْبَرَنَا عَبْدُ، الرَّزَّاقِ أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُتْبَةَ، أَنَّ أَبَا عَمْرِو بْنَ حَفْصِ بْنِ الْمُغِيرَةِ، خَرَجَ مَعَ عَلِيِّ بْنِ أَبِي طَالِبٍ إِلَى الْيَمَنِ فَأَرْسَلَ إِلَى امْرَأَتِهِ فَاطِمَةَ بِنْتِ قَيْسٍ بِتَطْلِيقَةٍ كَانَتْ بَقِيَتْ مِنْ طَلاَقِهَا وَأَمَرَ لَهَا الْحَارِثَ بْنَ هِشَامٍ وَعَيَّاشَ بْنَ أَبِي رَبِيعَةَ بِنَفَقَةٍ فَقَالاَ لَهَا وَاللَّهِ مَا لَكِ نَفَقَةٌ إِلاَّ أَنْ تَكُونِي حَامِلاً ‏.‏ فَأَتَتِ النَّبِيَّ صلى الله عليه وسلم فَذَكَرَتْ لَهُ قَوْلَهُمَا ‏.‏ فَقَالَ ‏"‏ لاَ نَفَقَةَ لَكِ ‏"‏ ‏.‏ فَاسْتَأْذَنَتْهُ فِي الاِنْتِقَالِ فَأَذِنَ لَهَا ‏.‏ فَقَالَتْ أَيْنَ يَا رَسُولَ اللَّهِ فَقَالَ ‏"‏ إِلَى ابْنِ أُمِّ مَكْتُومٍ ‏"‏ ‏.‏ وَكَانَ أَعْمَى تَضَعُ ثِيَابَهَا عِنْدَهُ وَلاَ يَرَاهَا فَلَمَّا مَضَتْ عِدَّتُهَا أَنْكَحَهَا النَّبِيُّ صلى الله عليه وسلم أُسَامَةَ بْنَ زَيْدٍ فَأَرْسَلَ إِلَيْهَا مَرْوَانُ قَبِيصَةَ بْنَ ذُؤَيْبٍ يَسْأَلُهَا عَنِ الْحَدِيثِ فَحَدَّثَتْهُ بِهِ فَقَالَ مَرْوَانُ لَمْ نَسْمَعْ هَذَا الْحَدِيثَ إِلاَّ مِنِ امْرَأَةٍ سَنَأْخُذُ بِالْعِصْمَةِ الَّتِي وَجَدْنَا النَّاسَ عَلَيْهَا ‏.‏ فَقَالَتْ فَاطِمَةُ حِينَ بَلَغَهَا قَوْلُ مَرْوَانَ فَبَيْنِي وَبَيْنَكُمُ الْقُرْآنُ قَالَ اللَّهُ عَزَّ وَجَلَّ ‏\{‏ لاَ تُخْرِجُوهُنَّ مِنْ بُيُوتِهِنَّ‏\}‏ الآيَةَ قَالَتْ هَذَا لِمَنْ كَانَتْ لَهُ مُرَاجَعَةٌ فَأَىُّ أَمْرٍ يَحْدُثُ بَعْدَ الثَّلاَثِ فَكَيْفَ تَقُولُونَ لاَ نَفَقَةَ لَهَا إِذَا لَمْ تَكُنْ حَامِلاً فَعَلاَمَ تَحْبِسُونَهَا\hadithno{3704}\hadithtrans{Ubaidullah b. 'Abdullah b. 'Utba reported that 'Amr b. Hafs b. al-Mughira set out along with 'Ali b. Abi Talib (Allah be pleased with him) to the Yemen and sent to his wife the one pronouncement of divorce which was still left from the (irrevocable) divorce; and he commanded al-Harith b. Hisham and 'Ayyash b. Abu Rabi'a to give her maintenance allowance. They said to her:By Allah, there is no maintenance allowance for you, except in case you are pregnant. She came to Allah's Apostle (may peace he upon him) and mentioned their opinion to him, whereupon he said: There is no maintenance allowance for you. Then she sought permission to move (to another place), and he (the Holy Prophet) permitted her. She said: Allah's Messenger, where (should I go)? He said: To the house of Ibn Umm Maktum and, as he is blind, she could put off her garmeqts in his presence and he would not see her. And when her 'Idda was over. Allah's Apostle (ﷺ) married her to Usama b. Zaid. Marwan (the governor of Medina) sent Qabisa b. Dhuwaib in order to ask her about this hadith, and she narrated it to him, whereupon Marwan said: We have not heard this hadith but from a woman. We would adopt a safe (path) where we found the people. Fatima said that when these words of, Marwan were conveyed to her. There is between me and you the word of Allah, the Exalted and Majestic: Do" not turn them out" of their houses. She asserted: This is in regard to the revocable divorce what new (turn can the event take) after three pronouncements (separation between irrevocable). Why do you say there is no maintenance allowance for her if she is not pregnant? Then on what ground do you restrain her?}}
\hadithdefcmd{muslim}{3705}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا هُشَيْمٌ، أَخْبَرَنَا سَيَّارٌ، وَحُصَيْنٌ، وَمُغِيرَةُ، وَأَشْعَثُ، وَمُجَالِدٌ وَإِسْمَاعِيلُ بْنُ أَبِي خَالِدٍ وَدَاوُدُ كُلُّهُمْ عَنِ الشَّعْبِيِّ، قَالَ دَخَلْتُ عَلَى فَاطِمَةَ بِنْتِ قَيْسٍ فَسَأَلْتُهَا عَنْ قَضَاءِ، رَسُولِ اللَّهِ صلى الله عليه وسلم عَلَيْهَا فَقَالَتْ طَلَّقَهَا زَوْجُهَا الْبَتَّةَ ‏.‏ فَقَالَتْ فَخَاصَمْتُهُ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فِي السُّكْنَى وَالنَّفَقَةِ - قَالَتْ - فَلَمْ يَجْعَلْ لِي سُكْنَى وَلاَ نَفَقَةً وَأَمَرَنِي أَنْ أَعْتَدَّ فِي بَيْتِ ابْنِ أُمِّ مَكْتُومٍ ‏.‏\hadithno{3705}\hadithtrans{Sha'bi reported:I visited Fatima bint Qais and asked her about the verdict of Allah's Messenger (ﷺ) about (board and lodging during the 'Idda) and she said that her husband divorced her with an irrevocable divorce. She (further. said): I contended with him before Allah's Messerger (ﷺ) about lodging and maintenance allowance, and she said: He did not provide me with any lodging or maintenance allowance, and he commanded me to spend the 'Idda in the house of Ibn Umm Maktum}}
\hadithdefcmd{muslim}{3706}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا هُشَيْمٌ، عَنْ حُصَيْنٍ، وَدَاوُدَ، وَمُغِيرَةَ، وَإِسْمَاعِيلَ، وَأَشْعَثَ عَنِ الشَّعْبِيِّ، أَنَّهُ قَالَ دَخَلْتُ عَلَى فَاطِمَةَ بِنْتِ قَيْسٍ ‏.‏ بِمِثْلِ حَدِيثِ زُهَيْرٍ عَنْ هُشَيْمٍ\hadithno{3706}\hadithtrans{A hadith like this has been trarismitted on the authority of Hushaim through another chain of narrators}}
\hadithdefcmd{muslim}{3707}{حَدَّثَنَا يَحْيَى بْنُ حَبِيبٍ، حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ الْهُجَيْمِيُّ، حَدَّثَنَا قُرَّةُ، حَدَّثَنَا سَيَّارٌ، أَبُو الْحَكَمِ حَدَّثَنَا الشَّعْبِيُّ، قَالَ دَخَلْنَا عَلَى فَاطِمَةَ بِنْتِ قَيْسٍ فَأَتْحَفَتْنَا بِرُطَبِ ابْنِ طَابٍ وَسَقَتْنَا سَوِيقَ سُلْتٍ فَسَأَلْتُهَا عَنِ الْمُطَلَّقَةِ، ثَلاَثًا أَيْنَ تَعْتَدُّ قَالَتْ طَلَّقَنِي بَعْلِي ثَلاَثًا فَأَذِنَ لِي النَّبِيُّ صلى الله عليه وسلم أَنْ أَعْتَدَّ فِي أَهْلِي ‏\hadithno{3707}\hadithtrans{Sha'bi reported:We visited Fatima bint Qais and she served us fresh dates and a drink of barley flour, and I asked her: Where should a woman who has been divorced by three pronouncements, spend the period of her 'Idda. She said: My husband divorced me with three pronouncements, and Allah's Apostle (ﷺ) permitted me to spend my 'Idda period with my family (with my parents)}}
\hadithdefcmd{muslim}{3708}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا سُفْيَانُ، عَنْ سَلَمَةَ بْنِ كُهَيْلٍ، عَنِ الشَّعْبِيِّ، عَنْ فَاطِمَةَ بِنْتِ قَيْسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم فِي الْمُطَلَّقَةِ ثَلاَثًا قَالَ ‏ "‏ لَيْسَ لَهَا سُكْنَى وَلاَ نَفَقَةٌ ‏"‏ ‏.‏\hadithno{3708}\hadithtrans{Fatima bint Qais (Allah be pleased with her) reported from Allah's Messenger (ﷺ) that there is no lodging and maintenance allowance for a woman who has been given irrevocable divorce}}
\hadithdefcmd{muslim}{3709}{وَحَدَّثَنِي إِسْحَاقُ بْنُ إِبْرَاهِيمَ الْحَنْظَلِيُّ، أَخْبَرَنَا يَحْيَى بْنُ آدَمَ، حَدَّثَنَا عَمَّارُ بْنُ، رُزَيْقٍ عَنْ أَبِي إِسْحَاقَ، عَنِ الشَّعْبِيِّ، عَنْ فَاطِمَةَ بِنْتِ قَيْسٍ، قَالَتْ طَلَّقَنِي زَوْجِي ثَلاَثًا فَأَرَدْتُ النُّقْلَةَ فَأَتَيْتُ النَّبِيَّ صلى الله عليه وسلم فَقَالَ ‏ "‏ انْتَقِلِي إِلَى بَيْتِ ابْنِ عَمِّكِ عَمْرِو بْنِ أُمِّ مَكْتُومٍ فَاعْتَدِّي عِنْدَهُ ‏"‏ ‏.‏\hadithno{3709}\hadithtrans{Fatima bint Qais (Allah be pleased with her) reported:My husband divorced me with three pronouncements. I decided to move (from his house to another place). So I came to Allah's Messenger (ﷺ), and he said: Move to the house of your cousin 'Amr b. Umm Maktum and spend your period of 'Idda there}}
\hadithdefcmd{muslim}{3710}{وَحَدَّثَنَاهُ مُحَمَّدُ بْنُ عَمْرِو بْنِ جَبَلَةَ، حَدَّثَنَا أَبُو أَحْمَدَ، حَدَّثَنَا عَمَّارُ بْنُ رُزَيْقٍ، عَنْ أَبِي إِسْحَاقَ، قَالَ كُنْتُ مَعَ الأَسْوَدِ بْنِ يَزِيدَ جَالِسًا فِي الْمَسْجِدِ الأَعْظَمِ وَمَعَنَا الشَّعْبِيُّ فَحَدَّثَ الشَّعْبِيُّ بِحَدِيثِ فَاطِمَةَ بِنْتِ قَيْسٍ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم لَمْ يَجْعَلْ لَهَا سُكْنَى وَلاَ نَفَقَةً ثُمَّ أَخَذَ الأَسْوَدُ كَفًّا مِنْ حَصًى فَحَصَبَهُ بِهِ ‏.‏ فَقَالَ وَيْلَكَ تُحَدِّثُ بِمِثْلِ هَذَا قَالَ عُمَرُ لاَ نَتْرُكُ كِتَابَ اللَّهِ وَسُنَّةَ نَبِيِّنَا صلى الله عليه وسلم لِقَوْلِ امْرَأَةٍ لاَ نَدْرِي لَعَلَّهَا حَفِظَتْ أَوْ نَسِيَتْ لَهَا السُّكْنَى وَالنَّفَقَةُ قَالَ اللَّهُ عَزَّ وَجَلَّ ‏\{‏ لاَ تُخْرِجُوهُنَّ مِنْ بُيُوتِهِنَّ وَلاَ يَخْرُجْنَ إِلاَّ أَنْ يَأْتِينَ بِفَاحِشَةٍ مُبَيِّنَةٍ‏\}‏ ‏.‏\hadithno{3710}\hadithtrans{Abu Ishaq reported:I was with al-Aswad b. Yazid sitting in the great mosque, and there was with us al-Sha'bi, and he narrated the narration of Fatima bint Qais (Allah be pleased with her) that Allah's Messenger (ﷺ) did not make any provision for lodging and maintenance allowance for her. Al-Aswad caught hold of some pebbles in his fist and he threw them towards him saying: Woe be to thee, you narrate like it, whereas Umar said: We cannot abandon the Book of Allah and the Sunnah of our Apostle (ﷺ) for the words of a woman. We do not know whether she remembers that or she forgets. For her, there is a provision of lodging and maintenance allowance. Allah, the Exalted and Majestic, said:" Turn them not from their houses nor should they themselves go forth unless they commit an open indecency" (lxv)}}
\hadithdefcmd{muslim}{3711}{وَحَدَّثَنَا أَحْمَدُ بْنُ عَبْدَةَ الضَّبِّيُّ، حَدَّثَنَا أَبُو دَاوُدَ، حَدَّثَنَا سُلَيْمَانُ بْنُ مُعَاذٍ، عَنْ أَبِي، إِسْحَاقَ بِهَذَا الإِسْنَادِ نَحْوَ حَدِيثِ أَبِي أَحْمَدَ عَنْ عَمَّارِ بْنِ رُزَيْقٍ، بِقِصَّتِهِ ‏.‏\hadithno{3711}\hadithtrans{A hadith like this has been narrated on the authority of Ishaq with the same chain of transmitters}}
\hadithdefcmd{muslim}{3712}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي بَكْرِ بْنِ أَبِي، الْجَهْمِ بْنِ صُخَيْرٍ الْعَدَوِيِّ قَالَ سَمِعْتُ فَاطِمَةَ بِنْتَ قَيْسٍ، تَقُولُ إِنَّ زَوْجَهَا طَلَّقَهَا ثَلاَثًا فَلَمْ يَجْعَلْ لَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم سُكْنَى وَلاَ نَفَقَةً قَالَتْ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِذَا حَلَلْتِ فَآذِنِينِي ‏"‏ ‏.‏ فَآذَنْتُهُ فَخَطَبَهَا مُعَاوِيَةُ وَأَبُو جَهْمٍ وَأُسَامَةُ بْنُ زَيْدٍ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَمَّا مُعَاوِيَةُ فَرَجُلٌ تَرِبٌ لاَ مَالَ لَهُ وَأَمَّا أَبُو جَهْمٍ فَرَجُلٌ ضَرَّابٌ لِلنِّسَاءِ وَلَكِنْ أُسَامَةُ بْنُ زَيْدٍ ‏"‏ ‏.‏ فَقَالَتْ بِيَدِهَا هَكَذَا أُسَامَةُ أُسَامَةُ فَقَالَ لَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ طَاعَةُ اللَّهِ وَطَاعَةُ رَسُولِهِ خَيْرٌ لَكِ ‏"‏ ‏.‏ قَالَتْ فَتَزَوَّجْتُهُ فَاغْتَبَطْتُ ‏.‏\hadithno{3712}\hadithtrans{Fatima bint Qais (Allah be pleased with her) reported that her husband divorced her with three, pronouncements and Allah's Messenger (ﷺ) made no provision for her lodging and maintenance allowance. She (further said):Allah's Messenger (ﷺ) said to me: When your period of 'Idda is over, inform me. So I informed him. (By that time) Mu'awiya, Abu Jahm and Usama b. Zaid had given her the proposal of marriage. Allah's Messenger (ﷺ) said: So far as Mu'awiya is concerned, he is a poor man without any property. So far as Abu Jahm is concerned, he is a great beater of women, but Usama b. Zaid... She pointed with her hand (that she did not approve of the idea of marrying) Usama. But Allah's Messenger (may peace be upon himn) said: Obedience to Allah and obedience to His Messenger is better for thee. She said: So I married him, and I became an object of envy}}
\hadithdefcmd{muslim}{3713}{وَحَدَّثَنِي إِسْحَاقُ بْنُ مَنْصُورٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ، عَنْ سُفْيَانَ، عَنْ أَبِي بَكْرِ بْنِ، أَبِي الْجَهْمِ قَالَ سَمِعْتُ فَاطِمَةَ بِنْتَ قَيْسٍ، تَقُولُ أَرْسَلَ إِلَىَّ زَوْجِي أَبُو عَمْرِو بْنُ حَفْصِ بْنِ الْمُغِيرَةِ عَيَّاشَ بْنَ أَبِي رَبِيعَةَ بِطَلاَقِي وَأَرْسَلَ مَعَهُ بِخَمْسَةِ آصُعِ تَمْرٍ وَخَمْسَةِ آصُعِ شَعِيرٍ فَقُلْتُ أَمَا لِي نَفَقَةٌ إِلاَّ هَذَا وَلاَ أَعْتَدُّ فِي مَنْزِلِكُمْ قَالَ لاَ ‏.‏ قَالَتْ فَشَدَدْتُ عَلَىَّ ثِيَابِي وَأَتَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ كَمْ طَلَّقَكِ ‏"‏ ‏.‏ قُلْتُ ثَلاَثًا ‏.‏ قَالَ ‏"‏ صَدَقَ لَيْسَ لَكِ نَفَقَةٌ ‏.‏ اعْتَدِّي فِي بَيْتِ ابْنِ عَمِّكِ ابْنِ أُمِّ مَكْتُومٍ فَإِنَّهُ ضَرِيرُ الْبَصَرِ تُلْقِي ثَوْبَكِ عِنْدَهُ فَإِذَا انْقَضَتْ عِدَّتُكِ فَآذِنِينِي ‏"‏ ‏.‏ قَالَتْ فَخَطَبَنِي خُطَّابٌ مِنْهُمْ مُعَاوِيَةُ وَأَبُو الْجَهْمِ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ إِنَّ مُعَاوِيَةَ تَرِبٌ خَفِيفُ الْحَالِ وَأَبُو الْجَهْمِ مِنْهُ شِدَّةٌ عَلَى النِّسَاءِ - أَوْ يَضْرِبُ النِّسَاءَ أَوْ نَحْوَ هَذَا - وَلَكِنْ عَلَيْكِ بِأُسَامَةَ بْنِ زَيْدٍ ‏"‏ ‏.‏\hadithno{3713}\hadithtrans{Fatima bint Qais (Allah be pleased with her) reported:My husband Abu 'Amr b. Hafs b. al-Mughira sent 'Ayyish b. Abu Rabi'a to me with a divorce, and he also sent through him five si's of dates and five si's of barley. I said: Is there no maintenance allowance for me but only this, and I cannot even spend my 'Idda period in your house? He said: No. She said: I dressed myself and came to Allah's Messenger (ﷺ). He said: How many pronouncements of divorce have been made for you? I said: Three. He said what he ('Ayyish b. Abu Rabi'a) had stated was true. There is no maintenance allowance for you. Spend 'Idda period in the house of your cousin, Ibn Umm Maktum. He is blind and you can put off your garment in his presence. And when you have spent your Idda period, you inform me. She said: Mu'awiya and Abu'l-Jahm (Allah be pleased with them) were among those who had given me the proposal of marriage. Thereupon Allah's Apostle (ﷺ) said: Mu'awiya is destitute and in poor condition and Abu'l-Jahm is very harsh with women (or he beats women, or like that), you should take Usama b. Zaid (as your husband)}}
\hadithdefcmd{muslim}{3714}{وَحَدَّثَنِي إِسْحَاقُ بْنُ مَنْصُورٍ، أَخْبَرَنَا أَبُو عَاصِمٍ، حَدَّثَنَا سُفْيَانُ الثَّوْرِيُّ، حَدَّثَنِي أَبُو بَكْرِ بْنُ أَبِي الْجَهْمِ، قَالَ دَخَلْتُ أَنَا وَأَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ عَلَى فَاطِمَةَ بِنْتِ قَيْسٍ فَسَأَلْنَاهَا فَقَالَتْ كُنْتُ عِنْدَ أَبِي عَمْرِو بْنِ حَفْصِ بْنِ الْمُغِيرَةِ فَخَرَجَ فِي غَزْوَةِ نَجْرَانَ ‏.‏ وَسَاقَ الْحَدِيثَ بِنَحْوِ حَدِيثِ ابْنِ مَهْدِيٍّ وَزَادَ قَالَتْ فَتَزَوَّجْتُهُ فَشَرَّفَنِي اللَّهُ بِابْنِ زَيْدٍ وَكَرَّمَنِي اللَّهُ بِابْنِ زَيْدٍ ‏.‏\hadithno{3714}\hadithtrans{Abu Bakr b. Abu'l-Jahm reported:I and Abu Salama b 'Abd al-Rahman came to fatima bint Qais (Al! ah be pleased with her) and asked her (about divorce, etc.). She said: I was the wife of Abu 'Amr b. Hafs b. al-Mughira, and he set out to join the battle of Najran. The rest of the hadith is the same, but he made this addition:" She said: I married him and Allah hornoured me on account of Ibn Zaid and Allah favoured me because of him}}
\hadithdefcmd{muslim}{3715}{وَحَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ الْعَنْبَرِيُّ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، حَدَّثَنِي أَبُو بَكْرٍ، قَالَ دَخَلْتُ أَنَا وَأَبُو سَلَمَةَ عَلَى فَاطِمَةَ بِنْتِ قَيْسٍ زَمَنَ ابْنِ الزُّبَيْرِ فَحَدَّثَتْنَا أَنَّ زَوْجَهَا طَلَّقَهَا طَلاَقًا بَاتًّا ‏.‏ بِنَحْوِ حَدِيثِ سُفْيَانَ ‏.‏\hadithno{3715}\hadithtrans{Abu Bakr reported:I and Abu Salama came to Fatima bint Qais (Allah be pleased with her) during the time of Ibn Zubair (Allah be pleased with him) and she narrated to us that her husband gave her an irrevocable divorce. (The rest of the hadith is the same)}}
\hadithdefcmd{muslim}{3716}{وَحَدَّثَنِي حَسَنُ بْنُ عَلِيٍّ الْحُلْوَانِيُّ، حَدَّثَنَا يَحْيَى بْنُ آدَمَ، حَدَّثَنَا حَسَنُ بْنُ صَالِحٍ، عَنِ السُّدِّيِّ، عَنِ الْبَهِيِّ، عَنْ فَاطِمَةَ بِنْتِ قَيْسٍ، قَالَتْ طَلَّقَنِي زَوْجِي ثَلاَثًا فَلَمْ يَجْعَلْ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم سُكْنَى وَلاَ نَفَقَةً ‏.‏\hadithno{3716}\hadithtrans{Fatima bint Qais (Allah be pleased with her) reported:My husband divorced me with three pronouncements and Allah's Messenger (ﷺ) made no provision for lodging and maintenance allowance}}
\hadithdefcmd{muslim}{3717}{وَحَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ هِشَامٍ، حَدَّثَنِي أَبِي قَالَ، تَزَوَّجَ يَحْيَى بْنُ سَعِيدِ بْنِ الْعَاصِ بِنْتَ عَبْدِ الرَّحْمَنِ بْنِ الْحَكَمِ فَطَلَّقَهَا فَأَخْرَجَهَا مِنْ عِنْدِهِ فَعَابَ ذَلِكَ عَلَيْهِمْ عُرْوَةُ فَقَالُوا إِنَّ فَاطِمَةَ قَدْ خَرَجَتْ ‏.‏ قَالَ عُرْوَةُ فَأَتَيْتُ عَائِشَةَ فَأَخْبَرْتُهَا بِذَلِكَ فَقَالَتْ مَا لِفَاطِمَةَ بِنْتِ قَيْسٍ خَيْرٌ فِي أَنْ تَذْكُرَ هَذَا الْحَدِيثَ ‏.‏\hadithno{3717}\hadithtrans{Hisham reported on the authority of his father that Yahya b. Sa'id b. al-'As married the daughter of 'Abd al-Rahman b. al-Hakam, and he divorced her and he turned her out from his house. 'Urwa (Allah be -pleased with him) criticised this (action) of theirs (the members of the family of her in-laws). They said:Verily, Fatima too went out (of her in-laws' house). 'Urwa said: I came to 'A'isha (Allah be pleased with her) and told her about it and she said: There is no good for Fatima bint Qais (Allah be pleased with her) in making mention of it}}
\hadithdefcmd{muslim}{3718}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا حَفْصُ بْنُ غِيَاثٍ، حَدَّثَنَا هِشَامٌ، عَنْ أَبِيهِ، عَنْ فَاطِمَةَ، بِنْتِ قَيْسٍ قَالَتْ قُلْتُ يَا رَسُولَ اللَّهِ زَوْجِي طَلَّقَنِي ثَلاَثًا وَأَخَافُ أَنْ يُقْتَحَمَ عَلَىَّ ‏.‏ قَالَ فَأَمَرَهَا فَتَحَوَّلَتْ ‏.‏\hadithno{3718}\hadithtrans{Fatima bint Qais (Allah be pleased with her) reported that she said:Allah's Messenger, my husband has divorcee me with three pronouncements and I am afraid that I may be put to hardship, and so he commanded her and so she moved (to another house)}}
\hadithdefcmd{muslim}{3719}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ عَبْدِ الرَّحْمَنِ، بْنِ الْقَاسِمِ عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّهَا قَالَتْ مَا لِفَاطِمَةَ خَيْرٌ أَنْ تَذْكُرَ هَذَا ‏.‏ قَالَ تَعْنِي قَوْلَهَا لاَ سُكْنَى وَلاَ نَفَقَةَ ‏.‏\hadithno{3719}\hadithtrans{A'isha (Allah be pleased with her) said:It is no good for Fatima to make mention of it, i. e. her statement:" There is no lodging and maintenance allowance (for the divorced women)}}
\hadithdefcmd{muslim}{3720}{وَحَدَّثَنِي إِسْحَاقُ بْنُ مَنْصُورٍ، أَخْبَرَنَا عَبْدُ الرَّحْمَنِ، عَنْ سُفْيَانَ، عَنْ عَبْدِ الرَّحْمَنِ، بْنِ الْقَاسِمِ عَنْ أَبِيهِ، قَالَ قَالَ عُرْوَةُ بْنُ الزُّبَيْرِ لِعَائِشَةَ أَلَمْ تَرَىْ إِلَى فُلاَنَةَ بِنْتِ الْحَكَمِ طَلَّقَهَا زَوْجُهَا الْبَتَّةَ فَخَرَجَتْ فَقَالَتْ بِئْسَمَا صَنَعَتْ ‏.‏ فَقَالَ أَلَمْ تَسْمَعِي إِلَى قَوْلِ فَاطِمَةَ فَقَالَتْ أَمَا إِنَّهُ لاَ خَيْرَ لَهَا فِي ذِكْرِ ذَلِكَ ‏.‏\hadithno{3720}\hadithtrans{Ibn al-Qasim narrated on the authority of his father that 'Urwa b. Zubair (Allah be pleased with him) said to 'A'isha (Allah be pleased with her):Didn't you see that such and such daughter of al-Hakam was divorced by her husband with an irrevocable divorce, and she left (the house of her husband)? Thereupon 'A'isha (Allah be pleased with her) said: It was bad that she did. He ( Urwa) said: Have you not heard the words of Fatima? Thereupon she said: There if no good for her in making mention of it}}
\hadithdefcmd{muslim}{3721}{وَحَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمِ بْنِ مَيْمُونٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنِ ابْنِ جُرَيْجٍ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، ح وَحَدَّثَنِي هَارُونُ بْنُ عَبْدِ اللَّهِ، - وَاللَّفْظُ لَهُ - حَدَّثَنَا حَجَّاجُ بْنُ مُحَمَّدٍ، قَالَ قَالَ ابْنُ جُرَيْجٍ أَخْبَرَنِي أَبُو الزُّبَيْرِ، أَنَّهُ سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ طُلِّقَتْ خَالَتِي فَأَرَادَتْ أَنْ تَجُدَّ نَخْلَهَا فَزَجَرَهَا رَجُلٌ أَنْ تَخْرُجَ فَأَتَتِ النَّبِيَّ صلى الله عليه وسلم فَقَالَ ‏ "‏ بَلَى فَجُدِّي نَخْلَكِ فَإِنَّكِ عَسَى أَنْ تَصَدَّقِي أَوْ تَفْعَلِي مَعْرُوفًا ‏"‏ ‏.‏\hadithno{3721}\hadithtrans{Jabir b. 'Abdullah (Allah be pleased with them) reported:My maternal aunt was divorced, and she intended to pluck her dates. A person scolded her for having come out (during the period of 'Idda). She came to Allah's Prophet (may peace be upon him.) and he said: Certainly you can pluck (dates) from your palm trees, for perhaps you may give charity or do an act of kindness}}
\hadithdefcmd{muslim}{3722}{وَحَدَّثَنِي أَبُو الطَّاهِرِ، وَحَرْمَلَةُ بْنُ يَحْيَى، - وَتَقَارَبَا فِي اللَّفْظِ - قَالَ حَرْمَلَةُ حَدَّثَنَا وَقَالَ أَبُو الطَّاهِرِ، أَخْبَرَنَا ابْنُ وَهْبٍ، - حَدَّثَنِي يُونُسُ بْنُ يَزِيدَ، عَنِ ابْنِ شِهَابٍ، حَدَّثَنِي عُبَيْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ بْنِ عُتْبَةَ بْنِ مَسْعُودٍ، أَنَّ أَبَاهُ، كَتَبَ إِلَى عُمَرَ بْنِ عَبْدِ اللَّهِ بْنِ الأَرْقَمِ الزُّهْرِيِّ يَأْمُرُهُ أَنْ يَدْخُلَ، عَلَى سُبَيْعَةَ بِنْتِ الْحَارِثِ الأَسْلَمِيَّةِ فَيَسْأَلَهَا عَنْ حَدِيثِهَا وَعَمَّا قَالَ لَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم حِينَ اسْتَفْتَتْهُ فَكَتَبَ عُمَرُ بْنُ عَبْدِ اللَّهِ إِلَى عَبْدِ اللَّهِ بْنِ عُتْبَةَ يُخْبِرُهُ أَنَّ سُبَيْعَةَ أَخْبَرَتْهُ أَنَّهَا كَانَتْ تَحْتَ سَعْدِ ابْنِ خَوْلَةَ وَهُوَ فِي بَنِي عَامِرِ بْنِ لُؤَىٍّ وَكَانَ مِمَّنْ شَهِدَ بَدْرًا فَتُوُفِّيَ عَنْهَا فِي حَجَّةِ الْوَدَاعِ وَهْىَ حَامِلٌ فَلَمْ تَنْشَبْ أَنْ وَضَعَتْ حَمْلَهَا بَعْدَ وَفَاتِهِ فَلَمَّا تَعَلَّتْ مِنْ نِفَاسِهَا تَجَمَّلَتْ لِلْخُطَّابِ فَدَخَلَ عَلَيْهَا أَبُو السَّنَابِلِ بْنُ بَعْكَكٍ - رَجُلٌ مِنْ بَنِي عَبْدِ الدَّارِ - فَقَالَ لَهَا مَا لِي أَرَاكِ مُتَجَمِّلَةً لَعَلَّكِ تَرْجِينَ النِّكَاحَ إِنَّكِ وَاللَّهِ مَا أَنْتِ بِنَاكِحٍ حَتَّى تَمُرَّ عَلَيْكِ أَرْبَعَةُ أَشْهُرٍ وَعَشْرٌ ‏.‏ قَالَتْ سُبَيْعَةُ فَلَمَّا قَالَ لِي ذَلِكَ جَمَعْتُ عَلَىَّ ثِيَابِي حِينَ أَمْسَيْتُ فَأَتَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَسَأَلْتُهُ عَنْ ذَلِكَ فَأَفْتَانِي بِأَنِّي قَدْ حَلَلْتُ حِينَ وَضَعْتُ حَمْلِي وَأَمَرَنِي بِالتَّزَوُّجِ إِنْ بَدَا لِي ‏.‏ قَالَ ابْنُ شِهَابٍ فَلاَ أَرَى بَأْسًا أَنْ تَتَزَوَّجَ حِينَ وَضَعَتْ وَإِنْ كَانَتْ فِي دَمِهَا غَيْرَ أَنْ لاَ يَقْرَبُهَا زَوْجُهَا حَتَّى تَطْهُرَ ‏.‏\hadithno{3722}\hadithtrans{Ubaidullah b. 'Abdullah b. 'Utba (b. Mas'ud) reported that his father wrote to Umar b. 'Abdullah b al Arqam al-Zuhri that he would go to Subai'ah bint al-Hirith al-Aslamiyya (Allah be pleased with her) and ask her about a verdict from him which Allah's Messenger (ﷺ) gave her when she had asked that from him (in regard to the termination of 'Idda at the birth of a child) 'Umar b. Abdullah wrote to 'Abdullah b. 'Utba informing him that Subai'ah had told him that she had been married to Sa'd b. Khaula and he belonged to the tribe of Amir b. Lu'ayy, and was one of those who participated in the Battle of Badr, and he died in the Farewell Pilgrimage and she had been in the family way at that time. And much time had not elapsed that she gave birth to a child after his death and when she was free from the effects of childbirth she embellished herself for those who had to give proposals of marriage. Abd al-Sunabil b. Ba'kak (from Banu 'Abd al-Dar) came to her and said:What is this that I see you embellished; perhaps you are inclined to marry, By Allah, you cannot marry unless four months and ten days (of 'Idda are passed). When he said that. I dressed myself, and as it was evening I came to Allah's Messenger (ﷺ) and asked him about it, and he gave me a religious verdict that I was allowed to marry when I had given birth to a child and asked me to marry if I so liked. Ibn Shihab said: I do not find any harm fur her in marrying when she has given birth to a child even when she is bleeding (after the birth of the child) except that her husband should not go near her until she is purified}}
\hadithdefcmd{muslim}{3723}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى الْعَنَزِيُّ، حَدَّثَنَا عَبْدُ الْوَهَّابِ، قَالَ سَمِعْتُ يَحْيَى بْنَ سَعِيدٍ، أَخْبَرَنِي سُلَيْمَانُ بْنُ يَسَارٍ، أَنَّ أَبَا سَلَمَةَ بْنَ عَبْدِ الرَّحْمَنِ، وَابْنَ، عَبَّاسٍ اجْتَمَعَا عِنْدَ أَبِي هُرَيْرَةَ وَهُمَا يَذْكُرَانِ الْمَرْأَةَ تُنْفَسُ بَعْدَ وَفَاةِ زَوْجِهَا بِلَيَالٍ ‏.‏ فَقَالَ ابْنُ عَبَّاسٍ عِدَّتُهَا آخِرُ الأَجَلَيْنِ ‏.‏ وَقَالَ أَبُو سَلَمَةَ قَدْ حَلَّتْ ‏.‏ فَجَعَلاَ يَتَنَازَعَانِ ذَلِكَ قَالَ فَقَالَ أَبُو هُرَيْرَةَ أَنَا مَعَ ابْنِ أَخِي - يَعْنِي أَبَا سَلَمَةَ - فَبَعَثُوا كُرَيْبًا - مَوْلَى ابْنِ عَبَّاسٍ - إِلَى أُمِّ سَلَمَةَ يَسْأَلُهَا عَنْ ذَلِكَ فَجَاءَهُمْ فَأَخْبَرَهُمْ أَنَّ أُمَّ سَلَمَةَ قَالَتْ إِنَّ سُبَيْعَةَ الأَسْلَمِيَّةَ نُفِسَتْ بَعْدَ وَفَاةِ زَوْجِهَا بِلَيَالٍ وَإِنَّهَا ذَكَرَتْ ذَلِكَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم فَأَمَرَهَا أَنْ تَتَزَوَّجَ ‏.‏\hadithno{3723}\hadithtrans{Abu Salama b. 'Abd al-Rahman and Ibn 'Abbas. (Allah be pleased with them) got together in the house of Abu Huraira (Allah be pleased with him) and began to discuss about the woman who gave birth to a child a few nights after the death of her husband. Ibn 'Abbas (Allah be pleased with then) ) said:Her 'Idda is that period which is longer of the two (between four months and ten days and the birth of the child, whichever is longer). AbuSalama, however said: Her period of 'Idda is over (with the birth of the child), and they were contending with each other over this issue, whereupon Abu Huraira (Allah be pleased with him) said: I subscribe (to the view) held by my nephew (i. e. Abu Salama). They sent Kuraib (the freed slave of Ibn 'Abbas) to Umm Salama to ask her about it. He came (back) to them and informed them that Umm Salama (Allah be pleased with her) said that Subai'ah al-Aslamiyya gave birth to a child after the death of her husband when the few flights (had hardly) passed and she made mention of that to Allah's Messenger (ﷺ) and he commanded her to marry}}
\hadithdefcmd{muslim}{3724}{وَحَدَّثَنَاهُ مُحَمَّدُ بْنُ رُمْحٍ، أَخْبَرَنَا اللَّيْثُ، ح وَحَدَّثَنَاهُ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَمْرٌو، النَّاقِدُ قَالاَ حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، كِلاَهُمَا عَنْ يَحْيَى بْنِ سَعِيدٍ، بِهَذَا الإِسْنَادِ ‏.‏ غَيْرَ أَنَّقَالَ فِي حَدِيثِهِ فَأَرْسَلُوا إِلَى أُمِّ سَلَمَةَ وَلَمْ يُسَمِّ كُرَيْبًا ‏.‏\hadithno{3724}\hadithtrans{This hadith has been narated with the same chain of transrmitters except with a small change of words (and that is):They sent him to Umm Salama, but no mention was made of Kuraib}}
\hadithdefcmd{muslim}{3728}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرٍ، عَنْ حُمَيْدِ بْنِ نَافِعٍ، عَنْ زَيْنَبَ بِنْتِ أَبِي سَلَمَةَ، أَنَّهَا أَخْبَرَتْهُ هَذِهِ الأَحَادِيثَ الثَّلاَثَةَ، قَالَ قَالَتْ زَيْنَبُ دَخَلْتُ عَلَى أُمِّ حَبِيبَةَ زَوْجِ النَّبِيِّ صلى الله عليه وسلم حِينَ تُوُفِّيَ أَبُوهَا أَبُو سُفْيَانَ فَدَعَتْ أُمُّ حَبِيبَةَ بِطِيبٍ فِيهِ صُفْرَةٌ خَلُوقٌ أَوْ غَيْرُهُ فَدَهَنَتْ مِنْهُ جَارِيَةً ثُمَّ مَسَّتْ بِعَارِضَيْهَا ثُمَّ قَالَتْ وَاللَّهِ مَا لِي بِالطِّيبِ مِنْ حَاجَةٍ غَيْرَ أَنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ عَلَى الْمِنْبَرِ ‏"‏ لاَ يَحِلُّ لاِمْرَأَةٍ تُؤْمِنُ بِاللَّهِ وَالْيَوْمِ الآخِرِ تُحِدُّ عَلَى مَيِّتٍ فَوْقَ ثَلاَثٍ إِلاَّ عَلَى زَوْجٍ أَرْبَعَةَ أَشْهُرٍ وَعَشْرًا ‏"‏ ‏.‏ قَالَتْ زَيْنَبُ ثُمَّ دَخَلْتُ عَلَى زَيْنَبَ بِنْتِ جَحْشٍ حِينَ تُوُفِّيَ أَخُوهَا فَدَعَتْ بِطِيبٍ فَمَسَّتْ مِنْهُ ثُمَّ قَالَتْ وَاللَّهِ مَا لِي بِالطِّيبِ مِنْ حَاجَةٍ غَيْرَ أَنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ عَلَى الْمِنْبَرِ ‏"‏ لاَ يَحِلُّ لاِمْرَأَةٍ تُؤْمِنُ بِاللَّهِ وَالْيَوْمِ الآخِرِ تُحِدُّ عَلَى مَيِّتٍ فَوْقَ ثَلاَثٍ إِلاَّ عَلَى زَوْجٍ أَرْبَعَةَ أَشْهُرٍ وَعَشْرًا ‏"‏ ‏.‏ قَالَتْ زَيْنَبُ سَمِعْتُ أُمِّي أُمَّ سَلَمَةَ، تَقُولُ جَاءَتِ امْرَأَةٌ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَتْ يَا رَسُولَ اللَّهِ إِنَّ ابْنَتِي تُوُفِّيَ عَنْهَا زَوْجُهَا وَقَدِ اشْتَكَتْ عَيْنُهَا أَفَنَكْحُلُهَا فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ ‏"‏ ‏.‏ مَرَّتَيْنِ أَوْ ثَلاَثًا كُلَّ ذَلِكَ يَقُولُ لاَ ثُمَّ قَالَ ‏"‏ إِنَّمَا هِيَ أَرْبَعَةُ أَشْهُرٍ وَعَشْرٌ وَقَدْ كَانَتْ إِحْدَاكُنَّ فِي الْجَاهِلِيَّةِ تَرْمِي بِالْبَعَرَةِ عَلَى رَأْسِ الْحَوْلِ ‏"‏ ‏.‏ قَالَ حُمَيْدٌ قُلْتُ لِزَيْنَبَ وَمَا تَرْمِي بِالْبَعَرَةِ عَلَى رَأْسِ الْحَوْلِ فَقَالَتْ زَيْنَبُ كَانَتِ الْمَرْأَةُ إِذَا تُوُفِّيَ عَنْهَا زَوْجُهَا دَخَلَتْ حِفْشًا وَلَبِسَتْ شَرَّ ثِيَابِهَا وَلَمْ تَمَسَّ طِيبًا وَلاَ شَيْئًا حَتَّى تَمُرَّ بِهَا سَنَةٌ ثُمَّ تُؤْتَى بِدَابَّةٍ حِمَارٍ أَوْ شَاةٍ أَوْ طَيْرٍ فَتَفْتَضُّ بِهِ فَقَلَّمَا تَفْتَضُّ بِشَىْءٍ إِلاَّ مَاتَ ثُمَّ تَخْرُجُ فَتُعْطَى بَعَرَةً فَتَرْمِي بِهَا ثُمَّ تُرَاجِعُ بَعْدُ مَا شَاءَتْ مِنْ طِيبٍ أَوْ غَيْرِهِ ‏.‏\hadithno{3728}\hadithtrans{Zainab (bint Abu Salama) (Allah be pleased with her) reported:I went to Umm Habiba, the wife of Allah's Apostle (ﷺ), when her father Abu Sufyan had died. Umm Habiba sent for a perfume having yellowness in it or something else like it, and she applied it to a girl and then rubbed it on her cheeks and then said: By Allah, I need no perfume but for the fact that I heard Allah's Messenger (ﷺ) say on the pulpit:" It is not permissible for a woman believing in Allah and the Hereafter to mourn for the dead beyond three days, but (in case of the death) of the husband it is permissible for four months and ten days." Zainab said: I then visited Zainab hint Jahsh (Allah be pleased with her) when her brother died and she sent for perfume and applied it and then said: By Allah, I don't feel any need for the perfume but that I heard Allah's Messenger (ﷺ) say on the pulpit:" It is not permissible for a woman believing in Allah and the Hereafbler to mourn the dead beyond three days except in case of her husband (for whom she can mourn) for four months and ten days." Zainab (Allah be pleased with her) said: I heard my mother Umm Salama (Allah be pleased with her) as saying: A woman came to Allah's Messenger (ﷺ) and said: Allah's Messenger. I have a daughter whose husband has died and there has developed some trouble in her eye; should we apply collyrium to it? Thereupon Allah's Messenger (ﷺ) said: No (repeating it twice or thrice, saying only, NO" all the time). Then he said: It is only four mouths and ten days, whereas in the preIslamic period none of you threw away the dung until one year had passed. Humaid said: I said to Zainab: What is this throwing of dung until a year is passed? Zainab said: When the husband of a woman died, she went into a hut and put on her worst clothes, and did not apply perfume or something like it until a year was over. Then an animal like a donkey, or a goat, or a bird was brought to her and she rubbed her hand over it, and it so happened that one on which she rubbed her hand died. She then came out of her house and she was given dung and she threw it and then she made use of anything like perfume or something else as she liked}}
\hadithdefcmd{muslim}{3729}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ حُمَيْدِ بْنِ نَافِعٍ، قَالَ سَمِعْتُ زَيْنَبَ بِنْتَ أُمِّ سَلَمَةَ، قَالَتْ تُوُفِّيَ حَمِيمٌ لأُمِّ حَبِيبَةَ فَدَعَتْ بِصُفْرَةٍ فَمَسَحَتْهُ بِذِرَاعَيْهَا وَقَالَتْ إِنَّمَا أَصْنَعُ هَذَا لأَنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ يَحِلُّ لاِمْرَأَةٍ تُؤْمِنُ بِاللَّهِ وَالْيَوْمِ الآخِرِ أَنْ تُحِدَّ فَوْقَ ثَلاَثٍ إِلاَّ عَلَى زَوْجٍ أَرْبَعَةَ أَشْهُرٍ وَعَشْرًا ‏"‏ ‏.‏\hadithno{3729}\hadithtrans{Zainab bint Umm Salama (Allah be pleased with her) reported that a relative of Umm Habiba (Allah he pleased with her) died. She sent for a yellow (perfume) and applied that to her forearm and said:I, am doing it, for I have heard Allah's Messenger (ﷺ) saying: It is not permissible for a woman believing in Allah and the Hereafter to mourn beyond three days except the husband (for whom she can mourn) for four months and ten days}}
\hadithdefcmd{muslim}{3731}{وَحَدَّثَتْهُ زَيْنَبُ، عَنْ أُمِّهَا، وَعَنْ زَيْنَبَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَوْ عَنِ امْرَأَةٍ مِنْ بَعْضِ أَزْوَاجِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{3731}\hadithtrans{This hadith was narrated by Zainab from her mother and from Zainab, the wife of Allah's Apostle (ﷺ), or from some other lady from among the wives of the Prophet (ﷺ)}}
\hadithdefcmd{muslim}{3732}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ حُمَيْدِ بْنِ نَافِعٍ، قَالَ سَمِعْتُ زَيْنَبَ بِنْتَ أُمِّ سَلَمَةَ، تُحَدِّثُ عَنْ أُمِّهَا، أَنَّ امْرَأَةً، تُوُفِّيَ زَوْجُهَا فَخَافُوا عَلَى عَيْنِهَا فَأَتَوُا النَّبِيَّ صلى الله عليه وسلم فَاسْتَأْذَنُوهُ فِي الْكُحْلِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ قَدْ كَانَتْ إِحْدَاكُنَّ تَكُونُ فِي شَرِّ بَيْتِهَا فِي أَحْلاَسِهَا - أَوْ فِي شَرِّ أَحْلاَسِهَا فِي بَيْتِهَا - حَوْلاً فَإِذَا مَرَّ كَلْبٌ رَمَتْ بِبَعَرَةٍ فَخَرَجَتْ أَفَلاَ أَرْبَعَةَ أَشْهُرٍ وَعَشْرًا ‏"‏ ‏.‏\hadithno{3732}\hadithtrans{Zainab bint Umm Salama (Allah be pleased with her) reported on the authority of her mother that a woman lost her husband. (As her eyes were ailing) they (her kith and kin) entertained fear about her eyes, so they came to Allah's Apostle (ﷺ) and sought permission for the use of collyrium, whereupon Allah's Messenger (ﷺ) said:One among you used to spend one year in a dungeon dressed in worst clothes. (And at the end of this period) she threw dung at the dog which happened to pass that way and then she came out (of her 'Idda). Can't she (wait) even for four months and ten days?}}
\hadithdefcmd{muslim}{3733}{وَحَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنْ حُمَيْدِ بْنِ نَافِعٍ، بِالْحَدِيثَيْنِ جَمِيعًا حَدِيثِ أُمِّ سَلَمَةَ فِي الْكُحْلِ وَحَدِيثِ أُمِّ سَلَمَةَ وَأُخْرَى مِنْ أَزْوَاجِ النَّبِيِّ صلى الله عليه وسلم غَيْرَ أَنَّهُ لَمْ تُسَمِّهَا زَيْنَبُ نَحْوَ حَدِيثِ مُحَمَّدِ بْنِ جَعْفَرٍ ‏.‏\hadithno{3733}\hadithtrans{Humaid b. Nafi' narrated two traditions from Umm Salama dealing with collyrium and the other hadith from the wives of Allah's Prophet (ﷺ) except with this that no mention was made of Zainab}}
\hadithdefcmd{muslim}{3734}{وَحَدَّثَنَا عَمْرٌو النَّاقِدُ، وَابْنُ أَبِي عُمَرَ، - وَاللَّفْظُ لِعَمْرٍو - حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ أَيُّوبَ بْنِ مُوسَى، عَنْ حُمَيْدِ بْنِ نَافِعٍ، عَنْ زَيْنَبَ بِنْتِ أَبِي سَلَمَةَ، قَالَتْ لَمَّا أَتَى أُمَّ حَبِيبَةَ نَعِيُّ أَبِي سُفْيَانَ دَعَتْ فِي الْيَوْمِ الثَّالِثِ بِصُفْرَةٍ فَمَسَحَتْ بِهِ ذِرَاعَيْهَا وَعَارِضَيْهَا وَقَالَتْ كُنْتُ عَنْ هَذَا غَنِيَّةً سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ يَحِلُّ لاِمْرَأَةٍ تُؤْمِنُ بِاللَّهِ وَالْيَوْمِ الآخِرِ أَنْ تُحِدَّ فَوْقَ ثَلاَثٍ إِلاَّ عَلَى زَوْجٍ فَإِنَّهَا تُحِدُّ عَلَيْهِ أَرْبَعَةَ أَشْهُرٍ وَعَشْرًا ‏"‏‏.‏\hadithno{3734}\hadithtrans{Zainab bint Abu Salama reported that when the news of the death of Abu Safyan came to Umm Habiba she sent for yellow (perfume) on the third day and rubbed it on her forearms and on her cheeks and said:I had in fact no need of it, but I heard Allah's Messenger (ﷺ) as saying: It is not permissible for the women believing in Allah and the Hereafter to abstain from adornment beyond three days except (at the death of) husband (in which case she must abstain from adornment) for four months and ten days}}
\hadithdefcmd{muslim}{3735}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَقُتَيْبَةُ، وَابْنُ، رُمْحٍ عَنِ اللَّيْثِ بْنِ سَعْدٍ، عَنْ نَافِعٍ، أَنَّ صَفِيَّةَ، بِنْتَ أَبِي عُبَيْدٍ حَدَّثَتْهُ عَنْ حَفْصَةَ، أَوْ عَنْ عَائِشَةَ، أَوْ عَنْ كِلْتَيْهِمَا، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَحِلُّ لاِمْرَأَةٍ تُؤْمِنُ بِاللَّهِ وَالْيَوْمِ الآخِرِ - أَوْ تُؤْمِنُ بِاللَّهِ وَرَسُولِهِ - أَنْ تُحِدَّ عَلَى مَيِّتٍ فَوْقَ ثَلاَثَةِ أَيَّامٍ إِلاَّ عَلَى زَوْجِهَا ‏"‏ ‏.‏\hadithno{3735}\hadithtrans{Safiyya bint Abu 'Ubaid reported on the authority of Hafsa or 'A'isha (Allah be pleased with thein) or from both of them that Allah's Messenger (may peace he upon him) said:It is not permissible for a woman believing in Allah and the Hereafter (or believing in Allah and His Messenger) that she should observe mourning for the dead beyond three days except in case of her husband}}
\hadithdefcmd{muslim}{3736}{وَحَدَّثَنَاهُ شَيْبَانُ بْنُ فَرُّوخَ، حَدَّثَنَا عَبْدُ الْعَزِيزِ، - يَعْنِي ابْنَ مُسْلِمٍ - حَدَّثَنَا عَبْدُ، اللَّهِ بْنُ دِينَارٍ عَنْ نَافِعٍ، بِإِسْنَادِ حَدِيثِ اللَّيْثِ ‏.‏ مِثْلَ رِوَايَتِهِ ‏.‏\hadithno{3736}\hadithtrans{A hadith like this is transmitted on the authority of Nafi}}
\hadithdefcmd{muslim}{3737}{وَحَدَّثَنَاهُ أَبُو غَسَّانَ الْمِسْمَعِيُّ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، قَالاَ حَدَّثَنَا عَبْدُ الْوَهَّابِ، قَالَ سَمِعْتُ يَحْيَى بْنَ سَعِيدٍ، يَقُولُ سَمِعْتُ نَافِعًا، يُحَدِّثُ عَنْ صَفِيَّةَ بِنْتِ أَبِي عُبَيْدٍ، أَنَّهَا سَمِعَتْ حَفْصَةَ بِنْتَ عُمَرَ، زَوْجَ النَّبِيِّ صلى الله عليه وسلم تُحَدِّثُ عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِ حَدِيثِ اللَّيْثِ وَابْنِ دِينَارٍ وَزَادَ ‏ "‏ فَإِنَّهَا تُحِدُّ عَلَيْهِ أَرْبَعَةَ أَشْهُرٍ وَعَشْرًا ‏"‏ ‏.‏\hadithno{3737}\hadithtrans{Safiyya bint Abu 'Ubaid reported that she heard Hafsa daughter of Umar (Allah be pleased with them), (and) wife of Allah's Prophet (ﷺ), narrating a hadith like this from Allah's Apostle (ﷺ), and she made this addition:" She should abstain from adorning herself (in case of the death of her husband) for four months and ten days}}
\hadithdefcmd{muslim}{3738}{وَحَدَّثَنَا أَبُو الرَّبِيعِ، حَدَّثَنَا حَمَّادٌ، عَنْ أَيُّوبَ، ح وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا عُبَيْدُ اللَّهِ، جَمِيعًا عَنْ نَافِعٍ، عَنْ صَفِيَّةَ بِنْتِ أَبِي عُبَيْدٍ، عَنْ بَعْضِ، أَزْوَاجِ النَّبِيِّ صلى الله عليه وسلم عَنِ النَّبِيِّ صلى الله عليه وسلم بِمَعْنَى حَدِيثِهِمْ ‏.‏\hadithno{3738}\hadithtrans{Safiyya bint Abu 'Ubaid narrated this tradition of Allah's Prophet (ﷺ) on the authority of some wives of Allah's Apostle (ﷺ)}}
\hadithdefcmd{muslim}{3739}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ وَعَمْرٌو النَّاقِدُ وَزُهَيْرُ بْنُ حَرْبٍ - وَاللَّفْظُ لِيَحْيَى - قَالَ يَحْيَى أَخْبَرَنَا وَقَالَ الآخَرُونَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَحِلُّ لاِمْرَأَةٍ تُؤْمِنُ بِاللَّهِ وَالْيَوْمِ الآخِرِ أَنْ تُحِدَّ عَلَى مَيِّتٍ فَوْقَ ثَلاَثٍ إِلاَّ عَلَى زَوْجِهَا ‏"‏ ‏.‏\hadithno{3739}\hadithtrans{A'isha (Allah be pleased with her) reported Allah's Messenger (ﷺ) as saying:It is not permissible for a woman believing in Allah and the Hereafter to observe mourning on the dead for more than three (days), except in case of her husband}}
\hadithdefcmd{muslim}{3740}{وَحَدَّثَنَا حَسَنُ بْنُ الرَّبِيعِ، حَدَّثَنَا ابْنُ إِدْرِيسَ، عَنْ هِشَامٍ، عَنْ حَفْصَةَ، عَنْ أُمِّ عَطِيَّةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تُحِدُّ امْرَأَةٌ عَلَى مَيِّتٍ فَوْقَ ثَلاَثٍ إِلاَّ عَلَى زَوْجٍ أَرْبَعَةَ أَشْهُرٍ وَعَشْرًا وَلاَ تَلْبَسُ ثَوْبًا مَصْبُوغًا إِلاَّ ثَوْبَ عَصْبٍ وَلاَ تَكْتَحِلُ وَلاَ تَمَسُّ طِيبًا إِلاَّ إِذَا طَهُرَتْ نُبْذَةً مِنْ قُسْطٍ أَوْ أَظْفَارٍ ‏"‏ ‏.‏\hadithno{3740}\hadithtrans{Umm `Atiyya (Allah be pleased with her) reported that Allah's Messenger (ﷺ) had said:A woman must not observe mourning for one who had died for more than three (days) except for four months and ten days in the case of her husband. And she must not wear a dyed garment except one of the types made of dyed yarn, or apply collyrium, or touch perfume except a little perfume or incense, when she has been purified after her courses}}
\hadithdefcmd{muslim}{3741}{وَحَدَّثَنَاهُ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، ح وَحَدَّثَنَا عَمْرٌو النَّاقِدُ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، كِلاَهُمَا عَنْ هِشَامٍ، بِهَذَا الإِسْنَادِ وَقَالاَ ‏ "‏ عِنْدَ أَدْنَى طُهْرِهَا نُبْذَةً مِنْ قُسْطٍ وَأَظْفَارٍ ‏"‏ ‏.‏\hadithno{3741}\hadithtrans{A hadith like this has been narrated on the authority of Hisham with the same chain of narrators but with a slight variation of words}}
\hadithdefcmd{muslim}{3742}{وَحَدَّثَنِي أَبُو الرَّبِيعِ الزَّهْرَانِيُّ، حَدَّثَنَا حَمَّادٌ، حَدَّثَنَا أَيُّوبُ، عَنْ حَفْصَةَ، عَنْ أُمِّ عَطِيَّةَ، قَالَتْ كُنَّا نُنْهَى أَنْ نُحِدَّ عَلَى مَيِّتٍ فَوْقَ ثَلاَثٍ إِلاَّ عَلَى زَوْجٍ أَرْبَعَةَ أَشْهُرٍ وَعَشْرًا وَلاَ نَكْتَحِلُ وَلاَ نَتَطَيَّبُ وَلاَ نَلْبَسُ ثَوْبًا مَصْبُوغًا وَقَدْ رُخِّصَ لِلْمَرْأَةِ فِي طُهْرِهَا إِذَا اغْتَسَلَتْ إِحْدَانَا مِنْ مَحِيضِهَا فِي نُبْذَةٍ مِنْ قُسْطٍ وَأَظْفَارٍ ‏.‏\hadithno{3742}\hadithtrans{Umm 'Atiyya ('Allah be pleased with her) said:We were forbidden to observe mourning for the dead beyond three days except in the case of husband (where it is permissible) for four months and ten days, and (that during this period) we should neither use collyrium nor touch perfume, nor wear dyed clothes, but concession was given to a woman when one of us was purified of our courses to make use of a little incense or scent}}
